@@ -28,14 +28,14 @@ Smb4KBookmarkHandler::Smb4KBookmarkHandler( QObject *parent, const char *name )
   // First we need the directory.
   KStandardDirs *stddir = new KStandardDirs();
   QString dir = locateLocal( "appdata", QString::null, KGlobal::instance() );
-  
+
   if ( !stddir->exists( dir ) )
   {
     stddir->makeDir( dir );
   }
 
   delete stddir;
-    
+
   // Do not use the KConfig object, that is provided by kapp->config().
   // We want a separate one for the passwords.
   m_config = new KConfig( "bookmarks", false, true, "appdata" );
@@ -47,7 +47,7 @@ Smb4KBookmarkHandler::Smb4KBookmarkHandler( QObject *parent, const char *name )
 Smb4KBookmarkHandler::~Smb4KBookmarkHandler()
 {
   writeBookmarkList( m_bookmarks );
-  
+
   m_bookmarks.clear();
 }
 
@@ -58,15 +58,15 @@ Smb4KBookmarkHandler::~Smb4KBookmarkHandler()
 
 void Smb4KBookmarkHandler::addBookmark( Smb4KBookmark *bookmark )
 {
-  if ( bookmark->getType() == "Printer" )
+  if ( QString::compare( bookmark->getType(), "Printer" ) == 0 )
   {
     emit error( ERROR_WRONG_BOOKMARK_TYPE );
     return;
   }
-  
+
   for ( QValueList<Smb4KBookmark *>::ConstIterator it = m_bookmarks.begin(); it != m_bookmarks.end(); ++it )
   {
-    if( (*it)->getShare().upper() == bookmark->getShare().upper() )
+    if( QString::compare( (*it)->getShare().upper(), bookmark->getShare().upper() ) == 0 )
     {
       //already exists
       return;
@@ -89,19 +89,19 @@ void Smb4KBookmarkHandler::writeBookmarkList( const QValueList<Smb4KBookmark *>
   {
     m_bookmarks = list;
   }
-  
+
   clear();
-  
+
   m_config->setGroup( "Bookmarks" );
   int i = 0;
-  
+
   for ( QValueListConstIterator<Smb4KBookmark *> it = m_bookmarks.begin(); it != m_bookmarks.end(); ++it )
   {
     m_config->writeEntry( QString( "%1" ).arg( i++ ), (*it)->getShare() );
   }
-  
+
   m_config->sync();
-  
+
   emit bookmarksUpdated();
 }
 
@@ -116,13 +116,13 @@ void Smb4KBookmarkHandler::loadBookmarks()
   {
     m_bookmarks.clear();
   }
-  
+
   m_config->setGroup( "Bookmarks" );
 
   for ( int index = 0; ; index++ )
   {
     QString bookmark = m_config->readEntry( QString( "%1" ).arg( index ), QString::null ).stripWhiteSpace();
-    
+
     if ( !bookmark.isEmpty() )
     {
       m_bookmarks.append( new Smb4KBookmark( bookmark, QString::null ) );
@@ -134,7 +134,7 @@ void Smb4KBookmarkHandler::loadBookmarks()
   }
 
   qHeapSort( m_bookmarks.end(), m_bookmarks.begin() );
-  
+
   emit bookmarksUpdated();
 }
 
@@ -147,7 +147,7 @@ void Smb4KBookmarkHandler::clear()
 {
   m_config->deleteGroup( "Bookmarks" );
   m_config->sync();
-  
+
   emit bookmarksUpdated();
 }
 
