@@ -32,24 +32,25 @@
 // Application includes
 #include "smb4kbookmark.h"
 
-/** 
+
+/**
  * This class belongs the to core classes of Smb4K and manages the
- * bookmarks. 
+ * bookmarks.
+ *
+ * @author         Alexander Reinholdt <dustpuppy@mail.berlios.de>
  */
 
 class Smb4KBookmarkHandler : public QObject
 {
   Q_OBJECT
-  
-  friend class Smb4KCore;
 
   public:
-    /** 
-     * The constructor. 
+    /**
+     * The constructor.
      */
     Smb4KBookmarkHandler( QObject *parent = 0, const char *name = 0 );
-    /** 
-     * The destructor. 
+    /**
+     * The destructor.
      */
     ~Smb4KBookmarkHandler();
     /**
@@ -62,18 +63,18 @@ class Smb4KBookmarkHandler : public QObject
      * deleted.
      */
     void writeBookmarkList( const QValueList<Smb4KBookmark *> &list );
-    /** 
-     * Load the bookmarks. 
+    /**
+     * Load the bookmarks.
      */
     void loadBookmarks();
-    /** 
-     * Get the list of bookmarks. 
+    /**
+     * Get the list of bookmarks.
      */
     const QValueList<Smb4KBookmark *> &getBookmarks() { return m_bookmarks; }
-    
+
   signals:
-    /** 
-     * Signal emitted when the list of bookmarks has been updated. 
+    /**
+     * Signal emitted when the list of bookmarks has been updated.
      */
     void bookmarksUpdated();
     /**
@@ -84,14 +85,14 @@ class Smb4KBookmarkHandler : public QObject
      * @param error_message The error message. Default is <code>QString::null</code>.
      */
     void error( int error_code, const QString &error_message = QString::null );
-    
+
   private:
-    /** 
-     * The KConfig object, that handles the bookmark file. 
+    /**
+     * The KConfig object, that handles the bookmark file.
      */
     KConfig *m_config;
-    /** 
-     * The list of bookmarks. 
+    /**
+     * The list of bookmarks.
      */
     QValueList<Smb4KBookmark *> m_bookmarks;
     /**
@@ -99,5 +100,4 @@ class Smb4KBookmarkHandler : public QObject
      */
     void clear();
 };
-
 #endif
