@@ -33,23 +33,30 @@
 // application specific includes
 #include "smb4kscanner.h"
 #include "smb4kmounter.h"
-#include "smb4kpasswdreader.h"
+#include "smb4kpasswordhandler.h"
 #include "smb4kfileio.h"
 #include "smb4kipfinder.h"
 #include "smb4kbookmarkhandler.h"
 #include "smb4kprint.h"
 #include "smb4kshellio.h"
+#include "smb4kglobal.h"
+#include "smb4kshare.h"
+
+using namespace Smb4K_Global;
+
+#define smb4k_core Smb4KCore::smb4kcore()
+
 
 
 /**
- * This is the top-level core class. It inherits all other core classes 
+ * This is the top-level core class. It inherits all other core classes
  * except the containers.
  */
 
 class Smb4KCore : public QObject
 {
   Q_OBJECT
-  
+
   public:
     /**
      * The constructor.
@@ -120,9 +127,9 @@ class Smb4KCore : public QObject
      */
     Smb4KIPFinder *ipFinder() { return m_finder; }
     /**
-     * Returns a pointer to the password reader object.
+     * Returns a pointer to the password handler object.
      */
-    Smb4KPasswdReader *passwdReader() { return m_passwdReader; }
+    Smb4KPasswordHandler *passwordHandler() { return m_password_handler; }
     /**
      * Returns a pointer to the printer handler object.
      */
@@ -141,42 +148,25 @@ class Smb4KCore : public QObject
      * @param share The share to be opened.
      */
     void open( Smb4KShare *share );
-    /**
-     * This function returns the UMASK as integer. It is provided 
-     * for convenience.
-     */
-    int getUMASK();
-    /**
-     * This function returns the Kernel version string. It is provided 
-     * for convenience.
-     */
-    const QString getKernelVersion();
-    /**
-     * This function returns the system name. It is provided 
-     * for convenience.
-     */
-    const QString getSystemName();
     /**
      * This function will return Samba's version string.
      */
     const QString getSambaVersion() { return m_samba_version; }
-    /**
-     * This function returns the global options of the smb.conf file. You 
-     * can reach the value of each option by providing the lowercase option 
-     * name as key, if it was defined in the global section of the smb.conf.
-     */
-    const QMap<QString, QString> getGlobalSambaOptions() { return m_fileIO->readSMBOptions(); }
-    /**
-     * This function returns the WINS server the system is using.
-     */
-    const QString getWINSServer();
     /**
      * Sets the share for which the usage should be returned. You may also pass
      * the NULL pointer. In this case, the usage() signal will return empty values.
-     * @param share The share object.
+     *
+     * @param share       The share object.
      */
     void setShareForUsageInfo( Smb4KShare *share );
-    
+    /**
+     * This function returns a static pointer to this class.
+     *
+     * @returns     a static pointer to this class.
+     */
+    static Smb4KCore *smb4kcore() { return m_this_class; }
+
+
   signals:
     /**
      * This signal is emitted, if one of the core objects
@@ -195,17 +185,17 @@ class Smb4KCore : public QObject
      * @param free          The space that's free (in kB).
      *
      * @param percent       The percentage the used space eats up (in kB).
-     * 
+     *
      * @param dirs          The number of directories present in the mount point. The items
      *                      '.' and '..' are ignored.
-     * 
+     *
      * @param files         The number of files present in the mount point.
      */
     void usage( const QString &mountpoint, double total, double used, double free, double percent, int dirs, int files );
-    
+
   protected slots:
     /**
-     * This slot is called, if the scanner is running. 
+     * This slot is called, if the scanner is running.
      */
     void slotScannerIsRunning( int state, bool on );
     /**
@@ -231,9 +221,10 @@ class Smb4KCore : public QObject
      */
     void slotShutdown();
     /**
-     * This slot receives the sambaVersion() signal by Smb4KShellIO and writes 
+     * This slot receives the sambaVersion() signal by Smb4KShellIO and writes
      * Samba's version to the config file.
-     * @param version Samba's version string.
+     *
+     *  @param version Samba's version string.
      */
     void slotReceiveSambaVersion( const QString &version );
     /**
@@ -247,7 +238,7 @@ class Smb4KCore : public QObject
      * of a share and emits this data via the usage() signal.
      */
     void slotGetUsage();
-      
+
   private:
     /**
      * The scanner object.
@@ -269,10 +260,6 @@ class Smb4KCore : public QObject
      * The IP finder object.
      */
     Smb4KIPFinder *m_finder;
-    /**
-     * The password reader object.
-     */
-    Smb4KPasswdReader *m_passwdReader;
     /**
      * The printer handler object.
      */
@@ -281,6 +268,10 @@ class Smb4KCore : public QObject
      * The shell IO object.
      */
     Smb4KShellIO *m_shellIO;
+    /**
+     * The password handler pbject.
+     */
+    Smb4KPasswordHandler *m_password_handler;
     /**
      * The state the sanner is in.
      */
@@ -321,17 +312,14 @@ class Smb4KCore : public QObject
      * The advanced options for smbclient.
      */
     QString m_advancedSMBOptions;
-    /**
-     * The KConfig object.
-     */
-    KConfig *m_config;
     /**
      * Stores Samba's version string.
      */
     QString m_samba_version;
     /**
      * This function is used to set the current state of the core.
-     * @param state One of the states defined in smb4kdefs.h
+     *
+     *  @param state One of the states defined in smb4kdefs.h
      */
     void setCurrentState( int state );
     /**
@@ -347,6 +335,10 @@ class Smb4KCore : public QObject
      * The timer for retrieving the usage periodically.
      */
     QTimer *m_timer;
+    /**
+     * A static pointer to this class.
+     */
+    static Smb4KCore *m_this_class;
 };
- 
+
 #endif
