@@ -48,7 +48,7 @@
 #define ERROR_GETTING_MEMBERS               101
 #define ERROR_GETTING_SHARES                102
 #define ERROR_GETTING_PREVIEW               103
-#define ERROR_GETTING_INFO                  104  /* obsolete */
+#define ERROR_OPENING_WALLET                104
 #define ERROR_ALREADY_MOUNTED               105
 #define ERROR_UNMOUNTING_NOT_ALLOWED        106
 #define ERROR_MOUNTING_SHARE                107
@@ -74,5 +74,11 @@
 #define ERROR_IMPORTING_SHARES              127
 #define ERROR_COMMAND_NOT_FOUND             128
 #define ERROR_PRINTING                      129
+#define ERROR_CREATING_TEMP_DIR             130
+#define ERROR_CREATING_TEMP_FILE            131
+#define ERROR_DIRECTORY_NOT_FOUND           132
+#define ERROR_LOCK_FILE_IS_SYMLINK          133
+#define ERROR_SHARE_WENT_OFFLINE            134
+#define ERROR_GETTING_PERMISSIONS           135
 
 #endif
