@@ -26,6 +26,7 @@
 #include <qobject.h>
 #include <qmap.h>
 #include <qvaluelist.h>
+#include <qdir.h>
 
 // KDE includes
 #include <kprocess.h>
@@ -38,14 +39,13 @@
 /**
  * This class handles all IO operations on system files, that
  * are needed by Smb4K.
+ *
  * @author Alexander Reinholdt
  */
 
 class Smb4KFileIO : public QObject
 {
   Q_OBJECT
-  
-  friend class Smb4KCore;
 
   public:
     /**
@@ -69,24 +69,18 @@ class Smb4KFileIO : public QObject
      * @return true in case of success and false otherwise.
      */
     bool removeSuperUserEntries();
-    /**
-     * Returns the map of global smb.conf options. You can reach the value
-     * of each option by providing the lowercase option name as key, if it 
-     * was defined in the global section of the smb.conf.
-     */
-    const QMap<QString, QString> readSMBOptions();
     /**
      * Returns the list of non-system users present on the system.
      */
     const QValueList<Smb4KUser *> getUsers();
     /**
-     * Returns the papersize defined on the system. Therefore the 
-     * /etc/papersize file is read. If this files does not exist, 
-     * this function will return 'a4' as value, the default value 
+     * Returns the papersize defined on the system. Therefore the
+     * /etc/papersize file is read. If this files does not exist,
+     * this function will return 'a4' as value, the default value
      * of enscript.
      */
     const QString getPaperSize();
-        /**
+    /**
      * This class holds the contents and the path of a file.
      */
     class FileItem
@@ -100,12 +94,12 @@ class Smb4KFileIO : public QObject
          * @param contents  The contents of the file.
          *
          * @param exists    Whether the file exists or not.
-        */
-        FileItem( const QString &path, const QStringList &contents, bool exists ) : m_path(path), m_contents(contents), m_exists(exists) {}
+         */
+        FileItem( const QString &path, const QString &permissions, const QStringList &contents, bool exists ) : m_path(path), m_permissions( permissions), m_contents(contents), m_exists(exists) {}
         /**
          * The empty constructor.
          */
-        FileItem() : m_path( QString::null ), m_contents( QStringList() ), m_exists( false ) {}
+        FileItem() : m_path( QString::null ), m_permissions( QString::null ), m_contents( QStringList() ), m_exists( false ) {}
         /**
          * The destructor.
          */
@@ -128,21 +122,44 @@ class Smb4KFileIO : public QObject
          * @param contents New contents of the file
          */
         void replaceContents( const QStringList &contents ) { m_contents = contents; }
-      
+        /**
+         * Returns the file name.
+         *
+         * @returns       The file name.
+         */
+        QString name() { return m_path.section( "/", -1, -1 ); }
+        /**
+         * Returns the permissions of the file in the form 0755 or similar.
+         * See the stat(2) manual page for more information.
+         *
+         * @returns       The permissions of the file.
+         */
+        QString permissions() { return m_permissions; }
+
       private:
         QString m_path;
+        QString m_permissions;
         QStringList m_contents;
         bool m_exists;
     };
+    /**
+     * This function converts the entries in the super.tab
+     * file to the new format.
+     */
+    void convertSuperTab();
+    /**
+     * This function does everything that has to be done on program exit.
+     */
+    void exit();
 
   signals:
     /**
-     * This signal emits the error code and an error message if 
+     * This signal emits the error code and an error message if
      * an error occurred.
      */
     void error( int error_code, const QString &error_message );
     /**
-     * This signal is emitted if something went wrong with writing the 
+     * This signal is emitted if something went wrong with writing the
      * suid program stuff.
      */
     void no_suid_program();
@@ -161,12 +178,12 @@ class Smb4KFileIO : public QObject
      * This slot is called, when the process exited.
      */
     void slotProcessExited( KProcess * );
+    /**
+     * This slot is called by the KApplication::shutDown() signal.
+     */
+    void slotShutdown();
 
   private:
-    /**
-     * KConfig object.
-     */
-    KConfig *m_config;
     /**
      * Enumeration to specify what is done.
      */
@@ -187,11 +204,6 @@ class Smb4KFileIO : public QObject
      * The KProcess object.
      */
     KProcess *m_proc;
-    /**
-     * This is a temporary funtion and converts the entries in the super.tab 
-     * file to the new format.
-     */
-    void convertSuperTab();
     /**
      * Locates a system config file, reads it contents and returns it. In case the
      * config file was not found, it emits and error and returns 0.
@@ -200,7 +212,7 @@ class Smb4KFileIO : public QObject
      *
      * @param strip    Decides whether the white spaces should be stripped. Default is FALSE.
      *
-     * @param quiet    If this is set to TRUE, there will be no error emitted if a config file 
+     * @param quiet    If this is set to TRUE, there will be no error emitted if a config file
      *                 could not be read.
      */
     Smb4KFileIO::FileItem readConfigFile( const QString &fileName, bool strip = false, bool quiet = false );
@@ -212,11 +224,30 @@ class Smb4KFileIO : public QObject
      *
      * @param permissions   This string holds the permissions the file should have.
      */
-    bool writeFile( Smb4KFileIO::FileItem *item, const QString &permissions );
+    bool writeFile( Smb4KFileIO::FileItem *item );
     /**
      * This function processes the sudoers file, i.e. is adds or removes entries.
      */
     void processSudoers();
+    /**
+     * This writes the lock file and does some additional tests.
+     *
+     * @param filename      Takes the name of the system file that should be edited. This parameter
+     *                      is not allowed to be empty.
+     *
+     * @returns             TRUE if the user is allowed to modify system files and FALSE otherwise
+     */
+    bool write_lock_file( const QString &filename );
+    /**
+     * Removes the lock file.
+     *
+     * @returns             TRUE on success and FALSE otherwise
+     */
+    bool remove_lock_file();
+    /**
+     * Contains the temporary directory.
+     */
+    QDir m_temp_dir;
 };
 
 #endif
