@@ -37,6 +37,8 @@
 #include "smb4kdefs.h"
 #include "smb4knetworkitems.h"
 
+
+
 /**
  * This class checks for the IP addresses of the hosts that were found by
  * the scanner.
@@ -87,7 +89,7 @@ class Smb4KIPFinder : public QObject
      * Takes the incoming data and puts it to the queue.
      */
     void slotInput( const QValueList<Smb4KHostItem *> &list );
-  
+
   private:
     /**
      * The KProcess object.
@@ -97,22 +99,10 @@ class Smb4KIPFinder : public QObject
      * The timer object.
      */
     QTimer *m_timer;
-    /**
-     * The buffer object.
-     */
-    QString m_buffer;
-    /**
-     * The host list.
-     */
-    QStringList m_hostList;
     /**
      * The current workgroup.
      */
     QString m_workgroup;
-     /**
-     * The KConfig object.
-     */
-    KConfig *m_config;
     /**
      * This bool is TRUE if the IP finder is working, else it is FALSE.
      */
@@ -121,11 +111,6 @@ class Smb4KIPFinder : public QObject
      * This list holds all hosts that need to get an IP address.
      */
     QPtrQueue<Smb4KHostItem> m_queue;
-    /**
-     * This function returns the advanced options for nmblookup, that the
-     * user chose to use via the configuration dialog.
-     */
-    const QString getNmblookupOptions();
 };
 
 #endif
