@@ -33,17 +33,17 @@
 #include <kconfig.h>
 
 // application specific includes
+#include "smb4kpasswordhandler.h"
 #include "smb4kshare.h"
 #include "smb4kdefs.h"
 
+
 /**
  * This is a core class. It mounts the shares.
  */
 class Smb4KMounter : public QObject
 {
   Q_OBJECT
-  
-  friend class Smb4KCore;
 
   public:
     /**
@@ -64,7 +64,7 @@ class Smb4KMounter : public QObject
      */
     enum State{ MountRecent, Import, Mount, Unmount, UnmountAll, ForceUnmount, Idle };
     /**
-     * Does everything, that has to be done on exit. 
+     * Does everything, that has to be done on exit.
      */
     void exit();
     /**
@@ -107,11 +107,11 @@ class Smb4KMounter : public QObject
      * This function returns TRUE if a share is mounted and FALSE otherwise.
      *
      * @param name The name of the share. It has to look like this: //HOST/SHARE.
-     * 
+     *
      * @return TRUE if the share is mounted and FALSE otherwise.
      */
     bool isMounted( const QString &name );
-    
+
   signals:
     /**
      * This signal is emitted, when a process starts or ends.
@@ -125,7 +125,7 @@ class Smb4KMounter : public QObject
     /**
      * Tells the program, that the shares list has been updated.
      */
-    void importedShares();
+    void updated();
     /**
      * This signal is emitted in case of an error occurred.
      *
@@ -136,6 +136,13 @@ class Smb4KMounter : public QObject
      *                        to figure this out.
      */
     void error( int error_code, const QString &error_message );
+    /**
+     * This signal is emitted if a share has successfully been mounted. It is
+     * not used by the main program, but may be used by plugins, etc.
+     *
+     * @param mountpoint      The mountpoint of the share.
+     */
+    void mountedShare( const QString &mountpoint );
 
   protected:
     /**
@@ -174,7 +181,7 @@ class Smb4KMounter : public QObject
      */
     void init();
     /**
-     * Initializes periodic checking. At the moment only the 
+     * Initializes periodic checking. At the moment only the
      * detection of mounted shares is supported.
      */
     void check();
@@ -206,7 +213,7 @@ class Smb4KMounter : public QObject
     void unmountAll();
     /**
      * This function returns the advanced option string that is needed to
-     * mount the shares. The contents is determined by the choice of the 
+     * mount the shares. The contents is determined by the choice of the
      * user (config dialog).
      */
     const QString getMountOptions();
@@ -214,10 +221,6 @@ class Smb4KMounter : public QObject
      * The KProcess object.
      */
     KProcess *m_proc;
-    /**
-     * The KConfig objects. With its help the options are read.
-     */
-    KConfig *m_config;
     /**
      * The buffer.
      */
@@ -283,6 +286,10 @@ class Smb4KMounter : public QObject
      * The CIFS login (user name).
      */
     QString m_cifs_login;
+    /**
+     * This is the password handler for this class.
+     */
+    Smb4KPasswordHandler *m_password_handler;
 };
 
 #endif
