@@ -21,7 +21,7 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
- 
+
 // Qt includes
 #include <qobject.h>
 #include <qstring.h>
@@ -34,19 +34,20 @@
 
 // application specific includes
 #include "smb4kprintinfo.h"
+#include "smb4kpasswordhandler.h"
 
 
 /**
- * This is a core class. It provides the interface for printing documents over 
+ * This is a core class. It provides the interface for printing documents over
  * the network neighborhood.
  *
  * You shouldn't use this class directly but access it through Smb4KCore.
  */
- 
+
 class Smb4KPrint : public QObject
 {
   Q_OBJECT
-  
+
   public:
     /**
      * The constructor.
@@ -65,18 +66,26 @@ class Smb4KPrint : public QObject
      * Aborts the print process.
      */
     void abort();
-    
+
   signals:
     /**
      * This signal is emitted, when the printing process started
      * or entered a different stage.
+     *
+     * @param mode          the run mode (see smb4kdefs.h)
+     *
+     * @param on            TRUE if the print handler is running and FALSE otherwise
      */
     void running( int mode, bool on );
     /**
      * This signal is emitted, if something went wrong.
+     *
+     * @param error_code    the error code (see smb4kdefs.h)
+     *
+     * @param error_message the error message
      */
     void error( int error_code, const QString &error_message );
-  
+
   protected:
     /**
      * Starts any process.
@@ -86,7 +95,7 @@ class Smb4KPrint : public QObject
      * Ends any process.
      */
     void endProcess();
-    
+
   protected slots:
     /**
      * This slot receives output at stdout.
@@ -100,11 +109,11 @@ class Smb4KPrint : public QObject
      * This slot is called when the process exited.
      */
     void slotProcessExited( KProcess * );
-     /**
+    /**
      * Is called, when the printing should be retried.
      */
     void slotRetry();
-     
+
   private:
     /**
      * The print info object.
@@ -114,10 +123,6 @@ class Smb4KPrint : public QObject
      * The KProcess object.
      */
     KProcess *m_proc;
-    /**
-     * The KConfig object.
-     */
-    KConfig *m_config;
     /**
      * The buffer.
      */
@@ -150,15 +155,14 @@ class Smb4KPrint : public QObject
      * Converts text file to PostScript usinf enscript.
      */
     void convertTextToPS();
-    /**
-     * This function returns the advanced options for smbclient, that the
-     * user chose to use via the configuration dialog.
-     */
-    const QString getSmbclientOptions();
     /**
      * The KFileItem object.
      */
     KFileItem *m_item;
+    /**
+     * The password handler of this class.
+     */
+    Smb4KPasswordHandler *m_password_handler;
 };
 
 #endif
