@@ -35,6 +35,8 @@
 // application specific includes
 #include "smb4kdefs.h"
 #include "smb4knetworkitems.h"
+#include "smb4kpasswordhandler.h"
+
 
 /**
  * This is the core class, that communicates with the network. All look-up
@@ -54,6 +56,10 @@ class Smb4KScanner : public QObject
      * The destructor.
      */
     ~Smb4KScanner();
+    /**
+     * Initiates a network scan.
+     */
+    void rescan();
     /**
      * Aborts the network scan.
      */
@@ -82,18 +88,17 @@ class Smb4KScanner : public QObject
      * Get the preview of a share.
      */
     void getPreview( const QString &workgroup, const QString &host, const QString &ip, const QString &share, const QString &path );
-    /** 
+    /**
      * This function returns an Smb4KWorkgroupItem, if the the workgroup
      * exists in the list, or 0, if it does not.
      */
-    Smb4KWorkgroupItem *getWorkgroup( const QString &workgroup );    
+    Smb4KWorkgroupItem *getWorkgroup( const QString &workgroup );
     /**
      * This function takes an Smb4KWorkgroupItem and appends it to the list, if the represented
      * workgroup isn't already in it.
      */
     void appendWorkgroup( Smb4KWorkgroupItem *item );
 
-    
   signals:
     /**
      * This signal is emitted, when the scanner starts and ends.
@@ -114,14 +119,14 @@ class Smb4KScanner : public QObject
     /**
      * This signal provides info about a certain host. It passes the server
      * and the OS string.
-     */   
+     */
     void info( Smb4KHostItem *host );
     /**
      * This signal is emitted, if the process was killed.
      */
     void killed();
     /**
-     * This signal emits the directory list of the share that is to be 
+     * This signal emits the directory list of the share that is to be
      * previewed or 0 if an error occurred.
      */
     void previewResult( const QValueList<Smb4KPreviewItem *> &list );
@@ -200,41 +205,27 @@ class Smb4KScanner : public QObject
     /**
      * Inits the network (re-)scan.
      */
-    void m_init();
+    void init();
     /**
      * Scans the group master for the group members.
      */
-    void m_scanForWorkgroupMembers( const QString &workgroup, const QString &master, const QString &ip );
+    void scanForWorkgroupMembers( const QString &workgroup, const QString &master, const QString &ip );
     /**
      * Scans the chosen host for its shares.
      */
-    void m_scanForShares( const QString &workgroup, const QString &host, const QString &ip );
+    void scanForShares( const QString &workgroup, const QString &host, const QString &ip );
     /**
      * Scans a given host for its OS and Server string.
      */
-    void m_scanForInfo( const QString &workgroup, const QString &host, const QString &ip );
+    void scanForInfo( const QString &workgroup, const QString &host, const QString &ip );
     /**
      * Searches for a given host.
      */
-    void m_searchForHost( const QString &host );
+    void searchForHost( const QString &host );
     /**
      * Gets a preview of a share.
      */
-    void m_previewShare( const QString &workgroup, const QString &host, const QString &ip, const QString &share, const QString &path );
-    /**
-     * This function returns the advanced options for nmblookup, that the
-     * user chose to use via the configuration dialog.
-     */
-    const QString getNmblookupOptions();
-    /**
-     * This function returns the advanced options for smbclient, that the
-     * user chose to use via the configuration dialog.
-     */
-    const QString getSmbclientOptions();
-    /**
-     * The KConfig object.
-     */
-    KConfig *m_config;
+    void preview( const QString &workgroup, const QString &host, const QString &ip, const QString &share, const QString &path );
     /**
      * Internal enumeration.
      */
@@ -287,7 +278,15 @@ class Smb4KScanner : public QObject
      * The list of workgroups including the master browser and their
      * IP addresses.
      */
-    QValueList<Smb4KWorkgroupItem *> m_workgroupList;
+    QValueList<Smb4KWorkgroupItem *> m_workgroup_list;
+    /**
+     * This list contains all host that Smb4K found in the network.
+     */
+    QValueList<Smb4KHostItem *> m_host_list;
+    /**
+     * This is the password handler for this class.
+     */
+    Smb4KPasswordHandler *m_password_handler;
 };
 
 #endif
