@@ -1,5 +1,5 @@
 /***************************************************************************
-    smb4kuser.cpp  -  This class provides a container for the user 
+    smb4kuser.cpp  -  This class provides a container for the user
     information that is read from /etc/passwd.
                              -------------------
     begin                : Mo Mr 1 2004
@@ -20,8 +20,8 @@
 #include <unistd.h>
 #include <sys/types.h>
 #include <pwd.h>
-#include <grp.h> 
- 
+#include <grp.h>
+
 // application specific includes
 #include "smb4kuser.h"
 
@@ -33,14 +33,14 @@ Smb4KUser::Smb4KUser( const int uid, const int gid ) : m_uid( uid ), m_gid( gid
     struct passwd p;
     struct passwd *p_ptr = &p;
     struct passwd *p_tmp;
-#ifndef __FreeBSD__    
+#ifndef __FreeBSD__
     char p_buf[sysconf( _SC_GETPW_R_SIZE_MAX )];
 #else
     char p_buf[250];
 #endif
     int p_buf_len = sizeof( p_buf );
-    
-    if ( (getpwuid_r( uid, p_ptr, p_buf, p_buf_len, &p_tmp )) != 0 )
+
+    if ( getpwuid_r( uid, p_ptr, p_buf, p_buf_len, &p_tmp ) != 0 )
     {
       qFatal( "Smb4KUser: Could not get user name!" );
     }
@@ -48,18 +48,14 @@ Smb4KUser::Smb4KUser( const int uid, const int gid ) : m_uid( uid ), m_gid( gid
     {
       m_user.append( p.pw_name );
     }
-    
+
     struct group g;
     struct group *g_ptr = &g;
     struct group *g_tmp;
-#ifndef __FreeBSD__
-    char g_buf[sysconf( _SC_GETGR_R_SIZE_MAX )];
-#else
     char g_buf[250];
-#endif
     int g_buf_len = sizeof( g_buf );
-    
-    if ( (getgrgid_r( gid, g_ptr, g_buf, g_buf_len, &g_tmp )) != 0 )
+
+    if ( getgrgid_r( gid, g_ptr, g_buf, g_buf_len, &g_tmp ) != 0 )
     {
       qFatal( "Smb4KUser: Could not get group name!" );
     }
@@ -69,7 +65,9 @@ Smb4KUser::Smb4KUser( const int uid, const int gid ) : m_uid( uid ), m_gid( gid
     }
   }
   else
-    qFatal( "Smb4KUser: UID and/or GID smaller than 0!" );    
+  {
+    qFatal( "Smb4KUser: UID and/or GID smaller than 0!" );
+  }
 }
 
 
