@@ -23,13 +23,12 @@
 
 #include "smb4k.h"
 
-Smb4KCore *app_core = 0L;
 
-static const char *description = 
+static const char *description =
 I18N_NOOP( "Smb4K is an SMB/CIFS share browser for KDE.\nIt uses Samba to access the local network neighborhood." );
 // INSERT A DESCRIPTION FOR YOUR APPLICATION HERE
-  
-  
+
+
 static KCmdLineOptions options[] =
 {
   { "+[File]", I18N_NOOP("file to open"), 0 },
@@ -42,99 +41,30 @@ void modifyConfig()
 {
   if ( kapp->config()->getConfigState() != KConfig::NoAccess && kapp->config()->getConfigState() != KConfig::ReadOnly )
   {
-    // Enter code to modify the config file here.
-    
-    // The following code can be removed in versions > 0.5.0
-    
-    kapp->config()->setGroup( "General Options" );
-    kapp->config()->deleteEntry( "Horizontal Splitter Sizes" );
-    kapp->config()->deleteEntry( "Vertical Splitter Sizes" );
-    kapp->config()->deleteEntry( "Main Window Geometry" );
+    kapp->config()->setGroup( "Samba" );
 
-    kapp->config()->setGroup( "System" );
-    kapp->config()->deleteEntry( "Name" );
-    kapp->config()->deleteEntry( "Version" );
-    kapp->config()->deleteEntry( "UID" );
-    kapp->config()->deleteEntry( "GID" );
-    kapp->config()->deleteEntry( "UMASK" );
-    kapp->config()->deleteEntry( "Samba" );
-  
-    kapp->config()->setGroup( "Mount Options" );
-    kapp->config()->deleteEntry( "Clean Up" );
-    
-    if ( kapp->config()->hasKey( "Allow Unmount Foreign" ) )
+    if ( kapp->config()->hasKey( "NMB Domain" ) )
     {
-      kapp->config()->writeEntry( "Unmount Foreign", kapp->config()->readBoolEntry( "Allow Unmount Foreign", false ) );
-      kapp->config()->deleteEntry( "Allow Unmount Foreign" );
+      kapp->config()->writeEntry( "Domain", kapp->config()->readEntry( "NMB Domain" ) );
+      kapp->config()->deleteEntry( "NMB Domain" );
     }
-  
-    if ( kapp->config()->hasKey( "Use SU Privileges" ) )
-    {
-      kapp->config()->writeEntry( "Run SUID", kapp->config()->readBoolEntry( "Use SU Privileges", false ) );
-      kapp->config()->writeEntry( "SUID Program", "super" );
-      kapp->config()->deleteEntry( "Use SU Privileges" );
-    }
-  
-    kapp->config()->deleteEntry( "Super" );
-    
-    QString suid_program;
-    bool force_umount, run_suid;
-    
-    if ( kapp->config()->hasKey( "SUID Program" ) )
-    {
-      suid_program = kapp->config()->readEntry( "SUID Program" );
-      kapp->config()->deleteEntry( "SUID Program" );
-    }
-    
-    if ( kapp->config()->hasKey( "Force Unmount" ) )
-    {
-      force_umount = kapp->config()->readBoolEntry( "Force Unmount" );
-      kapp->config()->deleteEntry( "Force Unmount" );      
-    }
-    
-    if ( kapp->config()->hasKey( "Run SUID" ) )
-    {
-      run_suid = kapp->config()->readBoolEntry( "Run SUID" );
-      kapp->config()->deleteEntry( "Run SUID" );
-    }
-
-    if ( !suid_program.isEmpty() )    
-    {
-      kapp->config()->setGroup( "Super User Privileges" );
-      kapp->config()->writeEntry( "Force Unmount", force_umount );
-      kapp->config()->writeEntry( "Run SUID", run_suid );
-      kapp->config()->writeEntry( "SUID Program", suid_program );
-    }
-    
-    kapp->config()->setGroup( "Browse Options" );
-    if ( kapp->config()->hasKey( "Host Needs Auth" ) )
-    {
-      kapp->config()->writeEntry( "Auth For Browse List", kapp->config()->readBoolEntry( "Host Needs Auth", false ) );
-      kapp->config()->deleteEntry( "Host Needs Auth" );
-    }
-    
-    kapp->config()->deleteEntry( "WINS Server" );
-    kapp->config()->deleteEntry( "WINS Support" );
-    
-    kapp->config()->deleteGroup( "Printing", true, false );
-    
-    kapp->config()->sync();
   }
 };
 
 
 
-int main(int argc, char *argv[])
+int main( int argc, char *argv[] )
 {
   KAboutData aboutData( "smb4k", I18N_NOOP( "Smb4K" ),
   VERSION, description, KAboutData::License_GPL,
-  I18N_NOOP( "(c) 2003, Alexander Reinholdt\n(c) 2004-2005, Alexander Reinholdt, Franck Babin" ), 0, "http://smb4k.berlios.de", "smb4k_bugs@web.de" );
+  I18N_NOOP( "(c) 2003, Alexander Reinholdt \n(c) 2004, Alexander Reinholdt, Franck Babin \n(c) 2005, The Smb4K team" ), 0, "http://smb4k.berlios.de", "smb4k_bugs@web.de" );
 
   // Authors:
   aboutData.addAuthor( "Alexander Reinholdt", I18N_NOOP( "Developer" ), "dustpuppy@users.berlios.de" );
+  aboutData.addAuthor( "Massimo Callegari", I18N_NOOP( "Developer" ), "massimocallegari@yahoo.it" );
   aboutData.addAuthor( "Franck Babin", I18N_NOOP( "Developer" ), "babinfranck@yahoo.ca" );
   aboutData.addAuthor( "Matthew P. Barnson", I18N_NOOP( "Documentation" ), "mbarnson@users.berlios.de" );
-  
+
   // All our credits:
   aboutData.addCredit( "Leopold Palomo Avellaneda", I18N_NOOP( "Catalan translation" ), "lepalom@wol.es" );
   aboutData.addCredit( "Radoslaw Zawartko", I18N_NOOP( "Polish translation" ), "radzaw@lnet.szn.pl" );
@@ -154,31 +84,40 @@ int main(int argc, char *argv[])
   aboutData.addCredit( "Alois Nešpor", I18N_NOOP( "Czech translation" ), "alois.nespor@seznam.cz" );
   aboutData.addCredit( "Martín Carr", I18N_NOOP( "Spanish translation" ), "tincarr@gmail.com" );
   aboutData.addCredit( "Görkem Çetin", I18N_NOOP( "Turkish translation" ), "gorkem@gorkemcetin.com" );
-  aboutData.addCredit( "Rashid N. Achilov", I18N_NOOP( "Testing of Smb4K under FreeBSD" ), "shelton@sentry.granch.ru" ); 
-   
+  aboutData.addCredit( "Jack Liu", I18N_NOOP( "Chinese Traditional translation" ), "chuany@chuany.net" );
+  aboutData.addCredit( "Arnar Leósson", I18N_NOOP( "Icelandic translation" ), "leosson@frisurf.no" );
+  aboutData.addCredit( "Rashid N. Achilov", I18N_NOOP( "Testing of Smb4K under FreeBSD" ), "shelton@sentry.granch.ru" );
+  aboutData.addCredit( "Michael Brinkloev", I18N_NOOP( "Danish translation" ), "mhb@qxp.dk" );
+  aboutData.addCredit( "Joop Beris", I18N_NOOP( "Dutch translation" ), "jberis@risse.nl" );
+
   KCmdLineArgs::init( argc, argv, &aboutData );
   KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
-
+  
   KUniqueApplication app;
 
-// This is for debugging only:    
-//  KApplication app;  
- 
+//  This is for debugging only:
+//   KApplication app;
+
   // Modify the configuration in case some entries changed:
   modifyConfig();
-  
-  app_core = new Smb4KCore( 0, "Core" );    
+
+  // You can access the core by including the header file smb4kcore.h
+  // and use the smb4k_core static variable variable or the smb4kcore()
+  // function.
+  new Smb4KCore( 0, "Core" );
   Smb4KApp *smb4k = new Smb4KApp( 0, "MainApp" );
-  
+
   app.setMainWidget( smb4k );
-  
+
   bool startDocked;
-  
-  KConfigGroup config(KGlobal::config(), "Settings");
-  startDocked = config.readBoolEntry("StartDocked", false);  
-  
+
+  KConfigGroup config( KGlobal::config(), "Settings" );
+  startDocked = config.readBoolEntry( "StartDocked", false );
+
   if ( !startDocked )
+  {
     smb4k->show();
+  }
 
   return app.exec();
 }
