@@ -26,6 +26,7 @@
 #include <kstdaction.h>
 #include <kmessagebox.h>
 #include <kpopupmenu.h>
+#include <kiconloader.h>
 
 // application specific includes
 #include "smb4k.h"
@@ -33,19 +34,18 @@
 #include "widgets/smb4koptionsdlg.h"
 #include "widgets/smb4kbookmarkeditor.h"
 #include "core/smb4kdefs.h"
+#include "core/smb4kglobal.h"
 
-Smb4KApp *Smb4KApp::sApp = 0L;
-extern Smb4KCore *app_core;
+using namespace Smb4K_Global;
 
 #define ID_STATUS_MSG 1
 
 
 Smb4KApp::Smb4KApp( QWidget* , const char* name ) : KDockMainWindow( 0, name )
 {
-  sApp = this;
   m_config = kapp->config();
   m_startDocked = false;
-  
+
   // The caption.
   setPlainCaption( i18n( "Smb4K - The SMB/CIFS Share Browser" ) );
 
@@ -57,22 +57,8 @@ Smb4KApp::Smb4KApp( QWidget* , const char* name ) : KDockMainWindow( 0, name )
   initActions();
   setupMenuBar();
   setupSystemTray();
-    
-  readOptions();
 
-  ///////////////////////////////////////////////////////////////////
-  // disable actions at startup
-  abort->setEnabled( false );
-  networkPreview->setEnabled( false );
-  sharesMount->setEnabled( false );
-  sharesUnmount->setEnabled( false );
-  sharesUnmountAll->setEnabled( false );
-  sharesForceUnmount->setEnabled( false );
-  sharesStartFilemanager->setEnabled( false );
-  networkAskPass->setEnabled( false );
-  networkPrint->setEnabled( false );
-  bookmarksAddBookmark->setEnabled( false );
-//  bookmarksEditBookmarks->setEnabled( false );
+  readOptions();
 }
 
 
@@ -83,41 +69,54 @@ Smb4KApp::~Smb4KApp()
 
 void Smb4KApp::initActions()
 {
+  // Add the action collections of the widgets to the main action collection.
+
   quitApp = KStdAction::quit( this, SLOT( slotQuit() ), actionCollection(), "quit_smb4k" );
 
   viewToolBar = KStdAction::showToolbar(this, SLOT(slotViewToolBar()), actionCollection());
   viewStatusBar = KStdAction::showStatusbar(this, SLOT(slotViewStatusBar()), actionCollection());
 
-  abort = new KAction( i18n( "&Abort" ) , "stop", CTRL+Key_A, this, SLOT( slotAbort() ), actionCollection(), "abort_action" );
-
-  networkRescan = new KAction( i18n( "&Rescan" ), "reload", CTRL+Key_R, m_core->scanner(), SLOT( slotInit() ), actionCollection(), "network_rescan" );
-  
-  networkSearch = new KAction( i18n( "&Search" ), "find", CTRL+Key_S, this, SLOT( slotShowSearchTab() ), actionCollection(), "network_search" );
-  
-  networkPreview = new KAction( i18n( "Pre&view" ), "view_icon", CTRL+Key_V, m_network_view, SLOT( slotPreview() ), actionCollection(), "network_preview" );
-  
-  networkAskPass = new KAction( i18n( "Au&thentication" ), "identity", CTRL+Key_T, m_network_view, SLOT( slotAskPass() ), actionCollection(), "network_askpass" );
-
-  networkPrint = new KAction( i18n( "&Print File" ), "printer1", CTRL+Key_P, m_network_view, SLOT( slotPrint() ), actionCollection(), "network_print" );
-    
-  sharesMount = new KAction( i18n( "&Mount" ), "hdd_mount", CTRL+Key_M, m_network_view, SLOT( slotMountShare() ), actionCollection(), "shares_mount" );
-  
-  sharesUnmount = new KAction( i18n( "&Unmount" ), "hdd_unmount", CTRL+Key_U, m_share_view, SLOT( slotUnmountShare() ), actionCollection(), "shares_unmount_share" );
-  
-  sharesForceUnmount = new KAction( i18n( "&Force Unmounting" ), "hdd_unmount", CTRL+Key_F, m_share_view, SLOT( slotForceUnmountShare() ), actionCollection(), "shares_force_unmount" );
-  
-  sharesUnmountAll = new KAction( i18n( "U&nmount All" ), "gear", CTRL+Key_N, m_share_view, SLOT( slotUnmountAllShares() ), actionCollection(), "shares_unmount_all" );
-  
-  sharesManualMount = new KAction( i18n( "M&ount Manually" ), "connect_creating", CTRL+Key_O, m_share_view, SLOT( slotManualMount() ), actionCollection(), "shares_manual_mount" );
-  
-  sharesStartFilemanager = new KAction( i18n( "&Konqueror" ), "kfm_home", CTRL+Key_K, m_share_view, SLOT( slotOpenFilemanager() ), actionCollection(), "shares_start_filemanager" );
-
-  bookmarksAddBookmark = new KAction( i18n( "&Add Bookmark" ), "bookmark_add", CTRL+Key_B, m_network_view, SLOT( slotAddBookmark() ), actionCollection(), "bookmarks_add_bookmark" );
-  
-  bookmarksEditBookmarks = new KAction( i18n( "&Edit Bookmarks" ), "bookmark", QString::null, this, SLOT( slotEditBookmarks() ), actionCollection(), "bookmarks_edit_bookmarks" );
-  
   settingsSmb4KOptions = KStdAction::preferences( this, SLOT( slotSmb4KOptionsDlg() ), actionCollection(), "configure_smb4k" );
-  
+
+  actionCollection()->insert( m_network_view->action_collection()->action( "abort" ) );
+  abort = m_network_view->action_collection()->action( "abort" );
+
+  actionCollection()->insert( m_network_view->action_collection()->action( "network_rescan" ) );
+  networkRescan = m_network_view->action_collection()->action( "network_rescan" );
+
+  actionCollection()->insert( m_network_view->action_collection()->action("network_search" ) );
+  networkSearch = m_network_view->action_collection()->action("network_search" );
+
+  actionCollection()->insert( m_network_view->action_collection()->action( "network_preview" ) );
+  networkPreview = m_network_view->action_collection()->action( "network_preview" );
+
+  actionCollection()->insert( m_network_view->action_collection()->action( "network_askpass" ) );
+  networkAskPass = m_network_view->action_collection()->action( "network_askpass" );
+
+  actionCollection()->insert( m_network_view->action_collection()->action( "network_print" ) );
+  networkPrint = m_network_view->action_collection()->action( "network_print" );
+
+  actionCollection()->insert( m_network_view->action_collection()->action( "network_mount" ) );
+  networkMount = m_network_view->action_collection()->action( "network_mount" );
+
+  actionCollection()->insert( m_network_view->action_collection()->action( "network_add_bookmark" ) );
+  networkAddBookmark = m_network_view->action_collection()->action( "network_add_bookmark" );
+
+  actionCollection()->insert( m_share_view->action_collection()->action( "shares_unmount_share" ) );
+  sharesUnmount = m_share_view->action_collection()->action( "shares_unmount_share" );
+
+  actionCollection()->insert( m_share_view->action_collection()->action( "shares_force_unmount" ) );
+  sharesForceUnmount = m_share_view->action_collection()->action( "shares_force_unmount" );
+
+  actionCollection()->insert( m_share_view->action_collection()->action( "shares_unmount_all" ) );
+  sharesUnmountAll = m_share_view->action_collection()->action( "shares_unmount_all" );
+
+  actionCollection()->insert( m_share_view->action_collection()->action( "shares_manual_mount" ) );
+  sharesManualMount = m_share_view->action_collection()->action( "shares_manual_mount" );
+
+  actionCollection()->insert( m_share_view->action_collection()->action( "shares_start_filemanager" ) );
+  sharesStartFilemanager = m_share_view->action_collection()->action( "shares_start_filemanager" );
+
   // use the absolute path to your smb4kui.rc file for testing purpose in createGUI();
   createGUI();
 }
@@ -158,9 +157,7 @@ void Smb4KApp::initStatusBar()
 
 void Smb4KApp::initCore()
 {
-  m_core = app_core;
-  
-  connect( m_core, SIGNAL( runStateChanged() ), this, SLOT( slotCoreRunStateChanged() ) );
+  connect( smb4k_core, SIGNAL( runStateChanged() ), this, SLOT( slotCoreRunStateChanged() ) );
 }
 
 
@@ -173,36 +170,47 @@ void Smb4KApp::initView()
   main->setEnableDocking( KDockWidget::DockNone );
   setView( main );
   setMainDockWidget( main );
-  
+
   KDockWidget *network = createDockWidget( "NetworkView", SmallIcon( "network" ), 0L, i18n( "Network Browser" ) );
   m_network_view = new Smb4KBrowserWidget( network );
   network->setWidget( m_network_view );
   network->manualDock( main, KDockWidget::DockLeft, 30 );
-  
+
   KDockWidget *tabs = createDockWidget( "TabsView", SmallIcon( "tab_new_raised" ), 0L, i18n( "Tab Widget" ) );
   KDockTabGroup *info = new KDockTabGroup( tabs, "TabGroup" );
   tabs->setWidget( info );
   tabs->manualDock( main, KDockWidget::DockBottom, 80 );
-  
+
   m_network_tab = new Smb4KNetworkTab( info );
   info->insertTab( m_network_tab, QIconSet( SmallIcon( "network" ), QIconSet::Automatic ), i18n( "Network" ), 0 );
- 
+
   m_share_tab = new Smb4KShareTab( info );
   info->insertTab( m_share_tab, QIconSet( SmallIcon( "hdd_mount" ), QIconSet::Automatic ), i18n( "Share" ), 1 );
- 
+
   m_search_tab = new Smb4KSearchTab( info );
   info->insertTab( m_search_tab, QIconSet( SmallIcon( "find" ), QIconSet::Automatic ), i18n( "Search" ), 2 );
 
+  connect( m_network_view, SIGNAL( searchRequest() ), this,                             SLOT( slotShowSearchTab() ) );
+  connect( m_network_view, SIGNAL( highlightedItem( QListViewItem * ) ), m_network_tab, SLOT( slotGetListViewItem( QListViewItem * ) ) );
+  connect( m_network_view, SIGNAL( cleared() ), m_network_tab,                          SLOT( slotClearWidget() ) );
+  connect( m_share_view,   SIGNAL( cleared() ), m_share_tab,                            SLOT( slotClearWidget() ) );
+  connect( m_share_view,   SIGNAL( clearedSelection() ), m_share_tab,                   SLOT( slotClearWidget() ) );
+  connect( m_search_tab,   SIGNAL( searchResult(Smb4KHostItem* ) ), m_network_view,     SLOT( slotInsertItem(Smb4KHostItem* ) ) );
+
   accel()->insert( i18n( "Show network tab" ), CTRL+Key_1, this, SLOT( slotShowNetworkTab() ), false, true );
   accel()->insert( i18n( "Show Share tab" ),   CTRL+Key_2, this, SLOT( slotShowShareTab() ),   false, true );
-  accel()->insert( i18n( "Show Search tab" ),  CTRL+Key_3, this, SLOT( slotShowSearchTab() ),  false, true );  
+  accel()->insert( i18n( "Show Search tab" ),  CTRL+Key_3, this, SLOT( slotShowSearchTab() ),  false, true );
 }
 
 
 void Smb4KApp::setupMenuBar()
 {
-  menuBar()->insertItem( i18n( "&Bookmarks" ), (new Smb4KBookmarkMenuWidget( Smb4KBookmarkMenuWidget::Normal, this, "BookmarkMenu" ))->popupMenu(), 3, 3 );
-  
+  Smb4KBookmarkMenuWidget *bookmark_menu = new Smb4KBookmarkMenuWidget( this, "BookmarkMenu" );
+
+  networkAddBookmark->plug( bookmark_menu->popupMenu(), 0 );
+
+  menuBar()->insertItem( i18n( "&Bookmarks" ), bookmark_menu->popupMenu(), 3, 3 );
+
   ((QPopupMenu *)(this->child( "settings" ) ))->insertItem( i18n( "&Dock Widgets" ), manager()->dockHideShowMenu(), 2, 2 );
 }
 
@@ -221,9 +229,9 @@ void Smb4KApp::saveOptions()
   m_config->writeEntry("Toolbar Position", (int)toolBar("mainToolBar")->barPos());
   m_config->writeEntry("Toolbar Text Position", toolBar("mainToolBar")->iconText());
   m_config->writeEntry("Toolbar Icon Size", toolBar("mainToolBar")->iconSize());
-  
+
   writeDockConfig( m_config, "General Options" );
-  
+
   KConfigGroup settingsConfig( KGlobal::config(), "Settings" );
   settingsConfig.writeEntry( "StartDocked", m_startDocked );
 }
@@ -257,15 +265,26 @@ void Smb4KApp::readOptions()
 
   // Set-up the status bar.
   m_config->setGroup( "Browse Options" );
-  if ( m_config->readEntry( "Browse List", "nmblookup" ) == "nmblookup" )
+  
+  if ( QString::compare( m_config->readEntry( "Browse List", "nmblookup" ), "nmblookup" ) == 0 )
+  {
     m_listLabel->setText( i18n( "Network" ) );
+  }
   else
+  {
     m_listLabel->setText( m_config->readEntry( "Query Host" ) );
+  }
+    
+  QString wins = getWINSServer();
 
-  if ( m_core->getWINSServer() != QString::null )
-    m_winsLabel->setText( m_core->getWINSServer() );
+  if ( QString::compare( wins, QString::null ) != 0 )
+  {
+    m_winsLabel->setText( wins );
+  }
   else
+  {
     m_winsLabel->setText( i18n( "None" ) );
+  }
 
   m_listLabel->setFixedWidth( m_listLabel->sizeHint().width() + 5 );
   m_winsLabel->setFixedWidth( m_winsLabel->sizeHint().width() + 5 );
@@ -280,15 +299,15 @@ bool Smb4KApp::queryExit()
 {
   m_startDocked = !this->isVisible();
   hide();
-  
+
   if ( sys_tray )
   {
     delete sys_tray;
     sys_tray = NULL;
   }
-  
+
   saveOptions();
-  
+
   return true;
 }
 
@@ -320,12 +339,12 @@ bool Smb4KApp::queryClose()
 void Smb4KApp::slotQuit()
 {
   slotStatusMsg(i18n("Exiting..."));
-  
+
   if ( sys_tray->isDocked() )
   {
     sys_tray->undock();
   }
-  
+
   KApplication::exit( 0 );
 }
 
@@ -333,24 +352,24 @@ void Smb4KApp::slotQuit()
 void Smb4KApp::slotAbort()
 {
   slotStatusMsg( i18n( "Aborting..." ) );
-  m_core->abort();
+  smb4k_core->abort();
   slotStatusMsg( i18n( "Done." ) );
 }
 
 
 void Smb4KApp::slotCoreRunStateChanged()
 {
-  int mode = m_core->currentState();
-  
-  if ( m_core->isRunning() )
+  int mode = smb4k_core->currentState();
+
+  if ( smb4k_core->isRunning() )
   {
     abort->setEnabled( true );
-    
-    if ( m_core->scannerIsRunning() )
+
+    if ( smb4k_core->scannerIsRunning() )
       networkRescan->setEnabled( false );
     else
       networkRescan->setEnabled( true );
-    
+
     switch ( mode )
     {
       case SCANNER_INIT:
@@ -361,16 +380,16 @@ void Smb4KApp::slotCoreRunStateChanged()
         break;
       case SCANNER_OPENING_HOST:
         slotStatusMsg( i18n( "Opening host..." ) );
-        break;   
+        break;
       case SCANNER_RETRIEVING_INFO:
         slotStatusMsg( i18n( "Retrieving information..." ) );
-        break;                
+        break;
       case SCANNER_RETRIEVING_PREVIEW:
         slotStatusMsg( i18n( "Retrieving preview..." ) );
-        break;      
+        break;
       case SCANNER_SEARCHING:
         slotStatusMsg( i18n( "Searching for host..." ) );
-        break;  
+        break;
       case IPFINDER_WORKING:
         slotStatusMsg( i18n( "Looking for IP addresses..." ) );
         break;
@@ -392,7 +411,7 @@ void Smb4KApp::slotCoreRunStateChanged()
       default:
         break;
     }
-    
+
     if ( !m_progTimer->isActive() )
     {
       // Start the busy progress bar:
@@ -401,11 +420,11 @@ void Smb4KApp::slotCoreRunStateChanged()
     }
   }
   else
-  {   
+  {
     m_progTimer->stop();
     m_progress->setTotalSteps( 100 );
     m_progress->reset();
-    networkRescan->setEnabled( true ); 
+    networkRescan->setEnabled( true );
     abort->setEnabled( false );
     slotStatusMsg( i18n( "Done." ) );
   }
@@ -473,10 +492,11 @@ void Smb4KApp::slotReadOptions()
 {
   m_network_view->readOptions();
   m_share_view->readOptions();
-  
+
   // Set-up the status bar.
   m_config->setGroup( "Browse Options" );
-  if ( m_config->readEntry( "Browse List", "nmblookup" ) == "nmblookup" )
+  
+  if ( QString::compare( m_config->readEntry( "Browse List", "nmblookup" ), "nmblookup" ) == 0 )
   {
     m_listLabel->setText( i18n( "Network" ) );
   }
@@ -484,10 +504,12 @@ void Smb4KApp::slotReadOptions()
   {
     m_listLabel->setText( m_config->readEntry( "Query Host" ) );
   }
+  
+  QString wins = getWINSServer();
 
-  if ( m_core->getWINSServer() != QString::null )
+  if ( QString::compare( wins, QString::null ) != 0 )
   {
-    m_winsLabel->setText( m_core->getWINSServer() );
+    m_winsLabel->setText( wins );
   }
   else
   {
@@ -499,31 +521,30 @@ void Smb4KApp::slotReadOptions()
 }
 
 
-void Smb4KApp::slotEditBookmarks()
-{
-  if ( child( "BookmarkEditor", "KDialogBase", true ) == 0 )
-  {
-    Smb4KBookmarkEditor *editor = new Smb4KBookmarkEditor( 0, "BookmarkEditor" );
-    editor->show();
-  }  
-}
-
-
 void Smb4KApp::slotShowNetworkTab()
 {
-  ((KDockTabGroup *)child( "TabGroup", "KDockTabGroup", true ))->showPage( m_network_tab );
+  if ( (KDockTabGroup *)child( "TabGroup", "KDockTabGroup", true ) && ((KDockTabGroup *)child( "TabGroup", "KDockTabGroup", true ))->isShown() )
+  {
+    ((KDockTabGroup *)child( "TabGroup", "KDockTabGroup", true ))->showPage( m_network_tab );
+  }
 }
 
 
 void Smb4KApp::slotShowShareTab()
 {
-  ((KDockTabGroup *)child( "TabGroup", "KDockTabGroup", true ))->showPage( m_share_tab );
+  if ( (KDockTabGroup *)child( "TabGroup", "KDockTabGroup", true ) && ((KDockTabGroup *)child( "TabGroup", "KDockTabGroup", true ))->isShown() )
+  {
+    ((KDockTabGroup *)child( "TabGroup", "KDockTabGroup", true ))->showPage( m_share_tab );
+  }
 }
 
 
 void Smb4KApp::slotShowSearchTab()
 {
-  ((KDockTabGroup *)child( "TabGroup", "KDockTabGroup", true ))->showPage( m_search_tab );
+  if ( (KDockTabGroup *)child( "TabGroup", "KDockTabGroup", true ) && ((KDockTabGroup *)child( "TabGroup", "KDockTabGroup", true ))->isShown() )
+  {
+    ((KDockTabGroup *)child( "TabGroup", "KDockTabGroup", true ))->showPage( m_search_tab );
+  }
 }
 
 #include "smb4k.moc"
