@@ -24,27 +24,35 @@
 #endif
 
 // KDE includes
-#include <kaction.h>
 #include <kactionclasses.h>
+#include <kactioncollection.h>
 
 class Smb4KBookmarkMenuWidget : public KActionMenu
 {
   Q_OBJECT
-  
+
   public:
     /**
      * The constructor.
      */
-    Smb4KBookmarkMenuWidget( int display_mode, QObject *parent= 0, const char *name = 0 );
+    Smb4KBookmarkMenuWidget( QObject *parent= 0, const char *name = 0 );
     /**
      * The destructor.
      */
     ~Smb4KBookmarkMenuWidget();
     /**
-     * This enumeration is for determing the display mode.
+     * This function returns a pointer to the action collection of this class.
+     * You should use it to include the action into the action collection of the
+     * main action collection (e.g. KMainWindow::actionCollection()).
+     *
+     * The entries in this action collection are only bookmarks and are members
+     * of the group "Bookmarks" (the bookmarks) and "BookmarkAction" (action to edit
+     * the bookmarks, etc.).
+     *
+     * @returns             a pointer to the action collection of this class
      */
-    enum Mode{ Tray, Normal };
-    
+    KActionCollection *action_collection() { return m_collection; }
+
   protected slots:
     /**
      * This slot is activated when the list of shares has been updated.
@@ -53,27 +61,40 @@ class Smb4KBookmarkMenuWidget : public KActionMenu
     void slotUpdatedShareList();
     /**
      * This slot is activated if an item in the menu has been activated.
-     * @param id The id of the activated item.
      */
-    void slotActivated( int id );
+    void slotActivated();
     /**
      * This slot is activated if the list of bookmarks has been updated.
      */
     void slotBookmarksUpdated();
-  
-  private:
     /**
-     * Initializes the actions.
+     * This slot is activated if the user wants to edit the bookmarks.
      */
-    void initActions();
+    void slotEditBookmarks();
+    /**
+     * This slot is activated whenever an action is highlighted.
+     *
+     * @param action        the action that is highlighted
+     */
+    void slotActionHighlighted( KAction *action );
+
+  private:
     /**
      * Inserts the bookmarks.
      */
     void insertBookmarks();
     /**
-     * Holds the diaplay mode.
+     * This function initializes the actions that are _not_ bookmarks.
      */
-    int m_display_mode;
+    void initActions();
+    /**
+     * This is the action collection of this class.
+     */
+    KActionCollection *m_collection;
+    /**
+     * The currently highlighted KAction.
+     */
+    KAction *m_action;
 };
 
 #endif
