@@ -17,32 +17,34 @@
 
 // Qt includes
 #include <qlayout.h>
-#include <qpainter.h>
 #include <qheader.h>
 #include <qvaluelist.h>
+#include <qlabel.h>
 
 // KDE includes
 #include <kapplication.h>
 #include <klocale.h>
-#include <kiconloader.h>
 #include <kmessagebox.h>
 #include <kdialogbase.h>
 #include <kglobalsettings.h>
 #include <kactionclasses.h>
 #include <kpopupmenu.h>
+#include <kiconloader.h>
 
 // application specific includes
 #include "smb4kbrowserwidget.h"
-#include "../smb4k.h"
 #include "smb4kpreviewdialog.h"
 #include "smb4kprintdialog.h"
 #include "../core/smb4kshare.h"
+#include "../core/smb4kcore.h"
+#include "../core/smb4kpasswordhandler.h"
+#include "../core/smb4kglobal.h"
+
+using namespace Smb4K_Global;
 
 
 Smb4KBrowserWidget::Smb4KBrowserWidget( QWidget *parent, const char *name ) : KListView( parent, name )
 {
-  m_config = kapp->config();
-
   setFrameShape( KListView::PopupPanel );
   setFrameShadow( KListView::Sunken );
   setRootIsDecorated( true );
@@ -52,20 +54,35 @@ Smb4KBrowserWidget::Smb4KBrowserWidget( QWidget *parent, const char *name ) : KL
   addColumn( i18n( "IP Address" ), -1 );
   addColumn( i18n( "Comment" ), -1 );
 
+  m_collection = new KActionCollection( this, "BrowserWidget_ActionCollection", KGlobal::instance() );
+
+  initActions();
+
   // Widget specific connections.
-  connect( this, SIGNAL( executed( QListViewItem * ) ),                                SLOT( slotItemExecuted( QListViewItem * ) ) );
-  connect( this, SIGNAL( expanded( QListViewItem * ) ),                                SLOT( slotItemExpandedCollapsed( QListViewItem * ) ) );
-  connect( this, SIGNAL( collapsed( QListViewItem * ) ),                               SLOT( slotItemExpandedCollapsed( QListViewItem * ) ) );
-  connect( this, SIGNAL( selectionChanged( QListViewItem * ) ),                        SLOT( slotSelectionChanged( QListViewItem * ) ) );
-  connect( this, SIGNAL( clicked( QListViewItem * ) ),                                 SLOT( slotItemClicked( QListViewItem * ) ) );
-  connect( this, SIGNAL( rightButtonPressed( QListViewItem *, const QPoint &, int ) ), SLOT( slotRightButtonPressed( QListViewItem *, const QPoint &, int ) ) );
+  connect( this, SIGNAL( executed( QListViewItem * ) ),
+           this, SLOT( slotItemExecuted( QListViewItem * ) ) );
+  connect( this, SIGNAL( expanded( QListViewItem * ) ),
+           this, SLOT( slotItemExpandedCollapsed( QListViewItem * ) ) );
+  connect( this, SIGNAL( collapsed( QListViewItem * ) ),
+           this, SLOT( slotItemExpandedCollapsed( QListViewItem * ) ) );
+  connect( this, SIGNAL( selectionChanged( QListViewItem * ) ),
+           this, SLOT( slotSelectionChanged( QListViewItem * ) ) );
+  connect( this, SIGNAL( clicked( QListViewItem * ) ),
+           this, SLOT( slotItemClicked( QListViewItem * ) ) );
+  connect( this, SIGNAL( rightButtonPressed( QListViewItem *, const QPoint &, int ) ),
+           this, SLOT( slotRightButtonPressed( QListViewItem *, const QPoint &, int ) ) );
 
   // External connections.
-  connect( sapp->core()->scanner(),   SIGNAL( workgroups( const QValueList<Smb4KWorkgroupItem *> & ) ), this, SLOT( slotWorkgroups( const QValueList<Smb4KWorkgroupItem *> & ) ) );
-  connect( sapp->core()->scanner(),   SIGNAL( members( const QValueList<Smb4KHostItem *> & ) ), this,         SLOT( slotMembers( const QValueList<Smb4KHostItem *> & ) ) );
-  connect( sapp->core()->scanner(),   SIGNAL( shares( const QValueList<Smb4KShareItem *> & ) ), this,         SLOT( slotShares( const QValueList<Smb4KShareItem *> & ) ) );
-  connect( sapp->core()->ipFinder(),  SIGNAL( ip_address( Smb4KHostItem * ) ), this,                          SLOT( slotAddIPAddress( Smb4KHostItem * ) ) );
-  connect( sapp->core()->mounter(),   SIGNAL( importedShares() ), this,                                       SLOT( slotMarkShares() ) );
+  connect( smb4k_core->scanner(),  SIGNAL( workgroups( const QValueList<Smb4KWorkgroupItem *> & ) ),
+           this,                   SLOT( slotWorkgroups( const QValueList<Smb4KWorkgroupItem *> & ) ) );
+  connect( smb4k_core->scanner(),  SIGNAL( members( const QValueList<Smb4KHostItem *> & ) ),
+           this,                   SLOT( slotMembers( const QValueList<Smb4KHostItem *> & ) ) );
+  connect( smb4k_core->scanner(),  SIGNAL( shares( const QValueList<Smb4KShareItem *> & ) ),
+           this,                   SLOT( slotShares( const QValueList<Smb4KShareItem *> & ) ) );
+  connect( smb4k_core->ipFinder(), SIGNAL( ip_address( Smb4KHostItem * ) ),
+           this,                   SLOT( slotAddIPAddress( Smb4KHostItem * ) ) );
+  connect( smb4k_core->mounter(),  SIGNAL( updated() ),
+           this,                   SLOT( slotMarkShares() ) );
 }
 
 
@@ -74,27 +91,67 @@ Smb4KBrowserWidget::~Smb4KBrowserWidget()
 }
 
 
+void Smb4KBrowserWidget::initActions()
+{
+  m_preview_action = new KAction( i18n( "Pre&view" ), "view_icon", CTRL+Key_V, this,          SLOT( slotPreview() ), m_collection, "network_preview" );
+  m_preview_action->setGroup( "BrowserWidget" );
+  m_preview_action->setEnabled( false );
+
+  m_askpass_action = new KAction( i18n( "Au&thentication" ), "identity", CTRL+Key_T, this,    SLOT( slotAskPass() ), m_collection, "network_askpass" );
+  m_askpass_action->setGroup( "BrowserWidget" );
+  m_askpass_action->setEnabled( false );
+
+  m_print_action = new KAction( i18n( "&Print File" ), "printer1", CTRL+Key_P, this,          SLOT( slotPrint() ), m_collection, "network_print" );
+  m_print_action->setGroup( "BrowserWidget" );
+  m_print_action->setEnabled( false );
+
+  m_mount_action = new KAction( i18n( "&Mount" ), "hdd_mount", CTRL+Key_M, this,              SLOT( slotMountShare() ), m_collection, "network_mount" );
+  m_mount_action->setGroup( "BrowserWidget" );
+  m_mount_action->setEnabled( false );
+
+  m_bookmark_action = new KAction( i18n( "&Add Bookmark" ), "bookmark_add", CTRL+Key_B, this, SLOT( slotAddBookmark() ), m_collection, "network_add_bookmark" );
+  m_bookmark_action->setGroup( "BrowserWidget" );
+  m_bookmark_action->setEnabled( false );
+
+  m_rescan_action = new KAction( i18n( "&Rescan" ), "reload", CTRL+Key_R, this,               SLOT( slotRescan() ), m_collection, "network_rescan" );
+  m_rescan_action->setGroup( "BrowserWidget" );
+  m_rescan_action->setEnabled( true );
+
+  m_abort_action = new KAction( i18n( "&Abort" ) , "stop", CTRL+Key_A, this,                  SLOT( slotAbort() ), m_collection, "abort" );
+  m_abort_action->setGroup( "BrowserWidget" );
+  m_abort_action->setEnabled( false );
+
+  m_search_action = new KAction( i18n( "&Search" ), "find", CTRL+Key_S, this,                 SLOT( slotSearch() ), m_collection, "network_search" );
+  m_search_action->setGroup( "BrowserWidget" );
+  m_search_action->setEnabled( true );
+}
+
+
 void Smb4KBrowserWidget::setOpen( QListViewItem *item, bool open )
 {
   if ( open && item->depth() == 0 )
   {
-    Smb4KWorkgroupItem *i = sapp->core()->scanner()->getWorkgroup( item->text( Network ) );
-    
-    sapp->core()->scanner()->getWorkgroupMembers( item->text( Network ), i->master(), i->ip() );
+    Smb4KWorkgroupItem *i = smb4k_core->scanner()->getWorkgroup( item->text( Network ) );
+
+    smb4k_core->scanner()->getWorkgroupMembers( item->text( Network ), i->master(), i->ip() );
   }
-  else if ( open && item->depth() == 1 ) //&& item->childCount() == 0 )
+  else if ( open && item->depth() == 1 )
   {
-    sapp->core()->scanner()->getShares( item->parent()->text( Network ), item->text( Network ), item->text( IP ) );
+    smb4k_core->scanner()->getShares( item->parent()->text( Network ), item->text( Network ), item->text( IP ) );
+    smb4k_core->scanner()->getInfo( item->parent()->text( Network ), item->text( Network ), item->text( IP ) );
   }
+
   KListView::setOpen( item, open );
 }
 
 
 void Smb4KBrowserWidget::insertItem( Smb4KHostItem *item )
 {
-  if ( sapp->core()->scanner()->getWorkgroup( item->workgroup() ) == 0 )
-    sapp->core()->scanner()->appendWorkgroup( new Smb4KWorkgroupItem( item->workgroup(), item->name(), item->ip() ) );  
-  
+  if ( smb4k_core->scanner()->getWorkgroup( item->workgroup() ) == 0 )
+  {
+    smb4k_core->scanner()->appendWorkgroup( new Smb4KWorkgroupItem( item->workgroup(), item->name(), item->ip() ) );
+  }
+
   // Now put the host into the list.
   QListViewItem *workgroupItem = findItem( item->workgroup(), Network, ExactMatch|CaseSensitive );
 
@@ -107,13 +164,15 @@ void Smb4KBrowserWidget::insertItem( Smb4KHostItem *item )
       Smb4KBrowserWidgetItem *newItem = new Smb4KBrowserWidgetItem( workgroupItem, item );
       newItem->setExpandable( true );
     }
-    else if ( hostItem != 0 && hostItem->parent()->text( Network ) != item->workgroup() )
+    else if ( hostItem != 0 && QString::compare( hostItem->parent()->text( Network ), item->workgroup() ) != 0 )
     {
       Smb4KBrowserWidgetItem *newItem = new Smb4KBrowserWidgetItem( workgroupItem, item );
       newItem->setExpandable( true );
     }
     else
+    {
       KMessageBox::sorry( this, i18n( "This computer is already in the list." ), QString::null, KMessageBox::Notify );
+    }
   }
   else
   {
@@ -129,10 +188,10 @@ void Smb4KBrowserWidget::insertItem( Smb4KHostItem *item )
 void Smb4KBrowserWidget::readOptions()
 {
   // Read the configuration.
-  m_config->setGroup( "Appearance" );
-  bool showType = m_config->readBoolEntry( "Show Type", true );
-  bool showComment = m_config->readBoolEntry( "Show Comment", true );
-  bool showIP = m_config->readBoolEntry( "Show IP", true );
+  config()->setGroup( "Appearance" );
+  bool showType = config()->readBoolEntry( "Show Type", true );
+  bool showComment = config()->readBoolEntry( "Show Comment", true );
+  bool showIP = config()->readBoolEntry( "Show IP", true );
 
   // Now put everything back in according to the wishes of the user.
   if ( showIP )
@@ -170,19 +229,22 @@ void Smb4KBrowserWidget::readOptions()
 
   // Adjust the columns. Avoid those that have a width of 0.
   int index = 0;
+
   while ( index < this->columns() )
   {
     if ( this->columnWidth( index ) != 0 )
+    {
       adjustColumn( index );
+    }
 
     index++;
   }
 
   // Initialize the rest.
-  m_hidden = m_config->readBoolEntry( "Show Hidden", true );
-  m_ipc = m_config->readBoolEntry( "Show IPC", false );
-  m_admin = m_config->readBoolEntry( "Show ADMIN", false );
-  m_printer = m_config->readBoolEntry( "Show Printer", true );
+  m_hidden = config()->readBoolEntry( "Show Hidden", true );
+  m_ipc = config()->readBoolEntry( "Show IPC", false );
+  m_admin = config()->readBoolEntry( "Show ADMIN", false );
+  m_printer = config()->readBoolEntry( "Show Printer", true );
 }
 
 
@@ -217,15 +279,20 @@ const QString Smb4KBrowserWidget::specifyUser( const QString &host )
   // for this 'homes' share.
   QStringList list;
 
-  if ( m_config->hasGroup( "Homes Shares" ) )
+  if ( config()->hasGroup( "Homes Shares" ) )
   {
-    m_config->setGroup( "Homes Shares" );
-    if ( m_config->hasKey( host ) )
-      list = m_config->readListEntry( host, ',' );
+    config()->setGroup( "Homes Shares" );
+
+    if ( config()->hasKey( host ) )
+    {
+      list = config()->readListEntry( host, ',' );
+    }
   }
 
   if ( !list.isEmpty() )
+  {
     username->insertStringList( list, -1 );
+  }
 
   username->setCurrentText( QString::null );
 
@@ -237,26 +304,32 @@ const QString Smb4KBrowserWidget::specifyUser( const QString &host )
   {
     // Write the new list of logins to the config file.
     if ( list.contains( username->currentText() ) == 0 )
+    {
       list.append( username->currentText() );
+    }
 
     int index = 0;
     while ( index < username->count() )
     {
       if ( list.contains( username->text( index ) ) == 0 )
+      {
         list.append( username->text( index ) );
+      }
 
       index++;
     }
 
     list.sort();
 
-    m_config->setGroup( "Homes Shares" );
-    m_config->writeEntry( host, list, ',' );
+    config()->setGroup( "Homes Shares" );
+    config()->writeEntry( host, list, ',' );
 
     return username->currentText();
   }
   else
+  {
     return QString::null;
+  }
 }
 
 
@@ -267,15 +340,22 @@ const QString Smb4KBrowserWidget::specifyUser( const QString &host )
 
 void Smb4KBrowserWidget::slotItemExecuted( QListViewItem *item )
 {
-  if ( item && item->depth() == 2 )
+  if ( item )
   {
-    if ( item->text( Type ).contains( "Printer" ) == 0 )
+    if ( item->depth() == 2 )
     {
-      slotMountShare();
+      if ( item->text( Type ).contains( "Printer" ) == 0 )
+      {
+        slotMountShare();
+      }
+      else
+      {
+        slotPrint();
+      }
     }
     else
     {
-      slotPrint();
+      setOpen( item, !item->isOpen() );
     }
   }
 }
@@ -291,60 +371,63 @@ void Smb4KBrowserWidget::slotSelectionChanged( QListViewItem *item )
 {
   if ( item && item->depth() == 2 )
   {
-    sapp->networkAskPass->setEnabled( true );
-    
+    m_preview_action->setEnabled( true );
+
     if ( item->text( Type ).contains( "Printer" ) == 0 )
     {
-      sapp->bookmarksAddBookmark->setEnabled( true );    
-      sapp->networkPreview->setEnabled( true );
-      sapp->sharesMount->setEnabled( true );
-      sapp->networkPrint->setEnabled( false );
+      m_bookmark_action->setEnabled( true );
+      m_preview_action->setEnabled( true );
+      m_mount_action->setEnabled( true );
+      m_print_action->setEnabled( false );
     }
     else
     {
-      sapp->bookmarksAddBookmark->setEnabled( false );
-      sapp->networkPreview->setEnabled( false );
-      sapp->sharesMount->setEnabled( false );
-      sapp->networkPrint->setEnabled( true );
+      m_bookmark_action->setEnabled( false );
+      m_preview_action->setEnabled( false );
+      m_mount_action->setEnabled( false );
+      m_print_action->setEnabled( true );
     }
   }
   else if ( item && item->depth() == 1 )
   {
-    sapp->bookmarksAddBookmark->setEnabled( false );
-    sapp->networkAskPass->setEnabled( true );
-    sapp->networkPreview->setEnabled( false );
-    sapp->networkPrint->setEnabled( false );
-    sapp->sharesMount->setEnabled( false );
+    m_bookmark_action->setEnabled( false );
+    m_askpass_action->setEnabled( true );
+    m_preview_action->setEnabled( false );
+    m_print_action->setEnabled( false );
+    m_mount_action->setEnabled( false );
   }
   else
   {
-    sapp->bookmarksAddBookmark->setEnabled( false );
-    sapp->networkPreview->setEnabled( false );
-    sapp->networkPrint->setEnabled( false );
-    sapp->sharesMount->setEnabled( false );
-    sapp->networkAskPass->setEnabled( false );
+    m_bookmark_action->setEnabled( false );
+    m_preview_action->setEnabled( false );
+    m_print_action->setEnabled( false );
+    m_mount_action->setEnabled( false );
+    m_askpass_action->setEnabled( false );
   }
 
   if ( item )
-    sapp->networkTab()->display( item );
+  {
+    emit highlightedItem( item );
+  }
 }
 
 
 void Smb4KBrowserWidget::slotRightButtonPressed( QListViewItem *, const QPoint &point, int )
 {
   KActionMenu *menu = new KActionMenu( this, "BrowserPopupMenu" );
+
   menu->popupMenu()->insertTitle( SmallIcon( "network" ), i18n( "Network" ), 0, 0 );
-  menu->insert( sapp->actionCollection()->action( "network_rescan" ) );
-  menu->insert( sapp->actionCollection()->action( "abort_action" ) );
+  menu->insert( m_rescan_action );
+  menu->insert( m_abort_action );
   menu->popupMenu()->insertSeparator( -1 );
-  menu->insert( sapp->actionCollection()->action( "network_search" ) );
+  menu->insert( m_search_action );
   menu->popupMenu()->insertSeparator( -1 );
-  menu->insert( sapp->actionCollection()->action( "bookmarks_add_bookmark" ) );
-  menu->insert( sapp->actionCollection()->action( "network_askpass" ) );
-  menu->insert( sapp->actionCollection()->action( "network_preview" ) );
-  menu->insert( sapp->actionCollection()->action( "network_print" ) );
-  menu->insert( sapp->actionCollection()->action( "shares_mount" ) );
-  
+  menu->insert( m_bookmark_action );
+  menu->insert( m_askpass_action );
+  menu->insert( m_preview_action );
+  menu->insert( m_print_action );
+  menu->insert( m_mount_action );
+
   menu->popupMenu()->exec( point, 0 );
 }
 
@@ -356,32 +439,33 @@ void Smb4KBrowserWidget::slotItemClicked( QListViewItem *item )
   // to disable some actions in the tool bar.
   if ( !item && !selectedItem() )
   {
-    sapp->bookmarksAddBookmark->setEnabled( false );
-    sapp->networkPreview->setEnabled( false );
-    sapp->networkPrint->setEnabled( false );
-    sapp->sharesMount->setEnabled( false );
-    sapp->networkAskPass->setEnabled( false );
+    m_bookmark_action->setEnabled( false );
+    m_preview_action->setEnabled( false );
+    m_print_action->setEnabled( false );
+    m_mount_action->setEnabled( false );
+    m_askpass_action->setEnabled( false );
 
-    sapp->networkTab()->display( item );
+    emit highlightedItem( item );
   }
 }
 
 
 void Smb4KBrowserWidget::slotWorkgroups( const QValueList<Smb4KWorkgroupItem *> &list )
 {
-  // Clear the network tab completely.
-  sapp->networkTab()->clear( 0 );
-
   // Clear the list view:
   clear();
 
+  emit cleared();
+
   // Adjust the columns.
   for ( int index = 0; index < columns(); index++ )
   {
     if ( this->columnWidth( index ) != 0 )
+    {
       adjustColumn( index );
+    }
   }
-  
+
   // Put the workgroups into the list view.
   if ( !list.isEmpty() )
   {
@@ -407,24 +491,28 @@ void Smb4KBrowserWidget::slotMembers( const QValueList<Smb4KHostItem *> &list )
   if ( !list.isEmpty() )
   {
     for ( QValueList<Smb4KHostItem *>::ConstIterator it = list.begin(); it != list.end(); ++it )
-    {      
+    {
       QListViewItem *item = this->findItem( (*it)->name(), Network, CaseSensitive|ExactMatch );
-        
+
       if ( item != 0 )
       {
-        if ( !((*it)->ip()).isEmpty() && item->text( IP ) != (*it)->ip() )
+        if ( !((*it)->ip()).isEmpty() && QString::compare( item->text( IP ), (*it)->ip() ) != 0 )
+        {
           item->setText( IP, (*it)->ip() );
-          
-        if ( !((*it)->comment()).isEmpty() && item->text( Comment ) != (*it)->comment() )
+        }
+
+        if ( !((*it)->comment()).isEmpty() && QString::compare( item->text( Comment ), (*it)->comment() ) != 0 )
+        {
           item->setText( Comment, (*it)->comment() );
-            
+        }
+
         continue;
       }
       else
       {
         Smb4KBrowserWidgetItem *host = new Smb4KBrowserWidgetItem( this->findItem( (*it)->workgroup(), Network, ExactMatch|CaseSensitive ), *it );
         host->setExpandable( true );
-      }            
+      }
     }
   }
 }
@@ -435,9 +523,9 @@ void Smb4KBrowserWidget::slotShares( const QValueList<Smb4KShareItem *> &list )
   if ( !list.isEmpty() )
   {
     for ( QValueList<Smb4KShareItem *>::ConstIterator it = list.begin(); it != list.end(); ++it )
-    {      
+    {
       QListViewItem *host = this->findItem( (*it)->host(), Network, ExactMatch|CaseSensitive );
-      
+
       if ( host != 0 )
       {
         if ( !m_hidden && (*it)->name().endsWith( "$" ) )
@@ -448,30 +536,34 @@ void Smb4KBrowserWidget::slotShares( const QValueList<Smb4KShareItem *> &list )
         {
           if ( !m_ipc && (*it)->name().contains( "IPC" ) != 0 )
             continue;
-            
+
           if ( !m_admin && (*it)->name().contains( "ADMIN" ) != 0 )
             continue;
         }
-        
-        if ( !m_printer && (*it)->name() == "Printer" )
+
+        if ( !m_printer && QString::compare( (*it)->name(), "Printer" ) == 0 )
+        {
           continue;
-      
+        }
+
         QListViewItem *test = findItem( (*it)->name(), Network, ExactMatch|CaseSensitive );
-        
+
         if ( test == 0 || test->parent() != host )
         {
           Smb4KBrowserWidgetItem *share = new Smb4KBrowserWidgetItem( host, *it );
           share->setExpandable( false );
-                    
+
           continue;
         }
         else if ( test != 0 && test->parent() == host )
         {
-          if ( !((*it)->comment()).isEmpty() && test->text( Comment ) != (*it)->comment() )
+          if ( !((*it)->comment()).isEmpty() && QString::compare( test->text( Comment ), (*it)->comment() ) != 0 )
+          {
             test->setText( Comment, (*it)->comment() );
-            
+          }
+
           continue;
-        }      
+        }
       }
     }
   }
@@ -482,14 +574,19 @@ void Smb4KBrowserWidget::slotMountShare()
 {
   if ( currentItem() && currentItem()->depth() == 2 )
   {
-    if ( currentItem()->text( Network ).stripWhiteSpace() == "homes" )
+    if ( QString::compare( currentItem()->text( Network ).stripWhiteSpace(), "homes" ) == 0 )
     {
       QString name = specifyUser( currentItem()->parent()->text( Network ) );
+
       if ( !name.isEmpty() )
-        sapp->core()->mounter()->mountShare( currentItem()->parent()->parent()->text( Network ), currentItem()->parent()->text( Network ), currentItem()->parent()->text( IP ), name );
+      {
+        smb4k_core->mounter()->mountShare( currentItem()->parent()->parent()->text( Network ), currentItem()->parent()->text( Network ), currentItem()->parent()->text( IP ), name );
+      }
     }
     else
-      sapp->core()->mounter()->mountShare( currentItem()->parent()->parent()->text( Network ), currentItem()->parent()->text( Network ), currentItem()->parent()->text( IP ), currentItem()->text( Network ) );
+    {
+      smb4k_core->mounter()->mountShare( currentItem()->parent()->parent()->text( Network ), currentItem()->parent()->text( Network ), currentItem()->parent()->text( IP ), currentItem()->text( Network ) );
+    }
   }
 }
 
@@ -502,7 +599,7 @@ void Smb4KBrowserWidget::slotAskPass()
     QString host = currentItem()->text( Network );
     QString share = QString::null;
 
-    sapp->core()->passwdReader()->askpass( workgroup, host, share, Smb4KPasswdReader::NewData );
+    smb4k_core->passwordHandler()->askpass( workgroup, host, share, Smb4KPasswordHandler::NewData );
   }
   else if ( currentItem() && currentItem()->depth() == 2 )
   {
@@ -510,7 +607,7 @@ void Smb4KBrowserWidget::slotAskPass()
     QString host = currentItem()->parent()->text( Network );
     QString share = currentItem()->text( Network );
 
-    sapp->core()->passwdReader()->askpass( workgroup, host, share, Smb4KPasswdReader::NewData );
+    smb4k_core->passwordHandler()->askpass( workgroup, host, share, Smb4KPasswordHandler::NewData );
   }
 }
 
@@ -521,12 +618,16 @@ void Smb4KBrowserWidget::slotPreview()
   QString host = currentItem()->parent()->text( Network );
   QString ip = currentItem()->parent()->text( IP );
   QString share;
-   
-  if ( currentItem()->text( Network ).stripWhiteSpace() == "homes" )
+
+  if ( QString::compare( currentItem()->text( Network ).stripWhiteSpace(), "homes" ) == 0 )
+  {
     share = specifyUser( currentItem()->parent()->text( Network ) );
+  }
   else
+  {
     share = currentItem()->text( Network );
-      
+  }
+
   Smb4KPreviewDialog *preview = new Smb4KPreviewDialog( workgroup, host, ip, share, this, 0, false );
   preview->show();
 }
@@ -536,32 +637,43 @@ void Smb4KBrowserWidget::slotAddBookmark()
 {
   if ( currentItem() && currentItem()->depth() == 2 )
   {
-    if ( currentItem()->text( Network ).stripWhiteSpace() != "homes" )
+    if ( QString::compare( currentItem()->text( Network ).stripWhiteSpace(), "homes" ) != 0 )
     {
       Smb4KBookmark *bookmark = new Smb4KBookmark( QString( "//%1/%2" ).arg( currentItem()->parent()->text( Network ), currentItem()->text( Network ) ), currentItem()->text( Type ) );
-      sapp->core()->bookmarkHandler()->addBookmark( bookmark );
+      smb4k_core->bookmarkHandler()->addBookmark( bookmark );
     }
     else
     {
       QString share = specifyUser( currentItem()->parent()->text( Network ) );
       Smb4KBookmark *bookmark = new Smb4KBookmark( QString( "//%1/%2" ).arg( currentItem()->parent()->text( Network ), share ), currentItem()->text( Type ) );
-      sapp->core()->bookmarkHandler()->addBookmark( bookmark );
+      smb4k_core->bookmarkHandler()->addBookmark( bookmark );
     }
   }
 }
 
 
+void Smb4KBrowserWidget::slotRescan()
+{
+  smb4k_core->scanner()->rescan();
+}
+
+
 void Smb4KBrowserWidget::slotAddIPAddress( Smb4KHostItem *item )
 {
   // First find the host and check wether it is the right one.
   QListViewItem *hostItem = findItem( item->name(), Network, ExactMatch|CaseSensitive );
 
-  if ( hostItem->parent()->text( Network ) == item->workgroup() )
+  // FIXME: This might be a potential problem, if there are several hosts
+  // with the same name in a domain/LAN.
+  // *** Question: Is this case at all possible? ***
+  if ( hostItem && hostItem->parent() && QString::compare( hostItem->parent()->text( Network ), item->workgroup() ) == 0 )
   {
     hostItem->setText( IP, item->ip() );
-    
+
     if ( this->columnWidth( IP ) != 0 )
+    {
       adjustColumn( IP );
+    }
   }
 }
 
@@ -578,28 +690,28 @@ void Smb4KBrowserWidget::slotPrint()
 
 void Smb4KBrowserWidget::slotMarkShares()
 {
-  m_config->setGroup( "Appearance" );  
-  bool show_all = m_config->readBoolEntry( "Show All Shares", false );
-  
+  config()->setGroup( "Appearance" );
+  bool show_all = config()->readBoolEntry( "Show All Shares", false );
+
   QListViewItemIterator it( this );
   QListViewItem *item;
-    
+
   while ((item = it.current()) != 0 )
   {
     ++it;
-      
+
     if ( item->depth() == 2 )
     {
-      Smb4KShare *share = sapp->core()->mounter()->findShareByName( QString( "//%1/%2" ).arg( item->parent()->text( Network ), item->text( Network ) ) );
-      
-      if ( sapp->core()->mounter()->isMounted( QString( "//%1/%2" ).arg( item->parent()->text( Network ), item->text( Network ) ) )
-           && ( !share->isForeign() || show_all ) )
+      Smb4KShare *share = smb4k_core->mounter()->findShareByName( QString( "//%1/%2" ).arg( item->parent()->text( Network ), item->text( Network ) ) );
+
+      if ( smb4k_core->mounter()->isMounted( QString( "//%1/%2" ).arg( item->parent()->text( Network ), item->text( Network ) ) ) &&
+           (!share->isForeign() || show_all) )
       {
         if ( !((Smb4KBrowserWidgetItem *)item)->isMounted() )
         {
           ((Smb4KBrowserWidgetItem *)item)->setMounted( true );
         }
-      
+
         continue;
       }
       else
@@ -609,72 +721,28 @@ void Smb4KBrowserWidget::slotMarkShares()
       }
     }
     else
+    {
       continue;
-  }
-} 
-
-
-
-/***************************************************************************
- *                                                                         *
- *   The Smb4KBrowserWidgetItem class.                                     *
- *                                                                         *
- ***************************************************************************/
-
-
-Smb4KBrowserWidgetItem::Smb4KBrowserWidgetItem( QListView *parent, Smb4KWorkgroupItem *item ) : QListViewItem( parent, item->workgroup() ), m_workgroup( m_workgroup ), m_host( NULL ), m_share( NULL ), m_mounted( false )
-{
-  setPixmap( 0, SmallIcon( "network" ) );
-}
-
-
-Smb4KBrowserWidgetItem::Smb4KBrowserWidgetItem( QListViewItem *parent, Smb4KHostItem *item ) : QListViewItem( parent, item->name(), QString::null, item->ip(), item->comment() ), m_workgroup( NULL ), m_host( item ), m_share( NULL ), m_mounted( false )
-{
-  setPixmap( 0, SmallIcon( "network_local" ) );
-}
-  
-
-Smb4KBrowserWidgetItem::Smb4KBrowserWidgetItem( QListViewItem *parent, Smb4KShareItem *item ) : QListViewItem( parent, item->name(), item->type(), QString::null, item->comment() ), m_workgroup( NULL ), m_host( NULL ), m_share( item ), m_mounted( false )
-{
-  if ( item->type().contains( "Printer" ) )
-    setPixmap( 0, SmallIcon( "printer1" ) );
-  else
-    setPixmap( 0, SmallIcon( "folder_green" ) );
-}
-
-
-Smb4KBrowserWidgetItem::~Smb4KBrowserWidgetItem()
-{
-}
-
-
-void Smb4KBrowserWidgetItem::setMounted( bool mounted )
-{
-  if ( depth() == 2 && text( 1 ) == "Disk" )
-  {
-    m_mounted = mounted;
-    
-    if ( mounted )
-      setPixmap( 0, SmallIcon( "folder_green_open" ) );
-    else
-      setPixmap( 0, SmallIcon( "folder_green" ) );
+    }
   }
 }
 
 
-void Smb4KBrowserWidgetItem::paintCell( QPainter *p, const QColorGroup &cg, int column, int width, int align )
+void Smb4KBrowserWidget::slotSearch()
 {
-  QFont f( p->font() );
-  
-  if ( m_mounted )
-    f.setItalic( true );    
-  else
-    f.setItalic( false );
-    
-  p->setFont( f );
-  
-  QListViewItem::paintCell( p, cg, column, width, align );
+  emit searchRequest();
 }
 
 
+void Smb4KBrowserWidget::slotInsertItem( Smb4KHostItem *item )
+{
+  insertItem( item );
+}
+
+
+void Smb4KBrowserWidget::slotAbort()
+{
+  smb4k_core->abort();
+}
+
 #include "smb4kbrowserwidget.moc"
