@@ -28,9 +28,12 @@
 // KDE includes
 #include <klistview.h>
 #include <kconfig.h>
+#include <kactioncollection.h>
+#include <kaction.h>
 
 // application specific includes
 #include "../core/smb4knetworkitems.h"
+#include "smb4kbrowserwidgetitem.h"
 
 
 /**
@@ -41,7 +44,6 @@ class Smb4KBrowserWidget : public KListView
 {
   Q_OBJECT
 
-  friend class Smb4KView;
   friend class Smb4KBrowserWidgetItem;
 
   public:
@@ -60,15 +62,37 @@ class Smb4KBrowserWidget : public KListView
       * look at the class documentation of KListView.
       */
     void setOpen( QListViewItem *item, bool on );
-    /**
-      * This function inserts a host item into the browser window.
-      */
-    void insertItem( Smb4KHostItem *item );
     /**
       * This function reads the options for the browser widget.
       */
     void readOptions();
-    
+    /**
+     * This function returns a pointer to the action collection of this class.
+     * You should use it to include the action into the action collection of the
+     * main action collection (e.g. KMainWindow::actionCollection()).
+     *
+     * The entries in this action collection are members of the group "BrowserWidget".
+     *
+     * @returns       a pointer to the action collection of this class
+     */
+    KActionCollection *action_collection() { return m_collection; }
+
+  signals:
+    /**
+     * This signal is emitted if the user wants to search for a share.
+     */
+    void searchRequest();
+    /**
+     * This signal emits the item that is currently highlighted.
+     *
+     * @param item    the item that's currently highlighted.
+     */
+    void highlightedItem( QListViewItem *item );
+    /**
+     * This signal is emitted when the browser widget has been cleared.
+     */
+    void cleared();
+
   protected slots:
     /**
      * Is called, when a list view item is to be mounted.
@@ -123,9 +147,14 @@ class Smb4KBrowserWidget : public KListView
      */
     void slotAddBookmark();
     /**
-     * Takes an Smb4KHostItem, extracts the IP address of the host and adds 
-     * it to the appropriate item in the KListView.
-     * @param item Smb4KHostItem for which the IP address should be entered
+     * This slot initializes a rescan of the network neighborhood.
+     */
+    void slotRescan();
+    /**
+     * Takes a reference to a Smb4KHostItem, extracts the IP address of the
+     * host and adds it to the appropriate item in the KListView.
+     *
+     * @param item      Smb4KHostItem which carries the IP address
      */
     void slotAddIPAddress( Smb4KHostItem *item );
     /**
@@ -133,16 +162,26 @@ class Smb4KBrowserWidget : public KListView
      */
     void slotPrint();
     /**
-     * This slot marks the mounted shares. It is called by the 
-     * Smb4KMounter::importedShares signal.
+     * This slot marks the mounted shares. It is called by the
+     * Smb4KMounter::updated() signal.
      */
     void slotMarkShares();
+    /**
+     * This slot is called when the user want to search for a share.
+     */
+    void slotSearch();
+    /**
+     * This slot inserts a host item into the browser widget.
+     *
+     * @param item      the item that should be inserted into the browser widget
+     */
+    void slotInsertItem( Smb4KHostItem *item );
+    /**
+     * This slot aborts all actions of the core.
+     */
+    void slotAbort();
 
   private:
-    /**
-     * The KConfig object.
-     */
-    KConfig *m_config;
     /**
      * This value is TRUE, if the hidden shares are to be shown, otherwise
      * it is FALSE.
@@ -172,82 +211,50 @@ class Smb4KBrowserWidget : public KListView
      * Enumeration for the columns in the list view.
      */
     enum Columns{ Network = 0, Type = 1, IP = 2, Comment = 3 };
-};
-
-
-/**
- * This class cares about the items that are inserted into the browser widget.
- */
-
-class Smb4KBrowserWidget;
-class Smb4KBrowserWidgetItem : public QListViewItem
-{
-  public:
     /**
-     * The constructor for toplevel (workgroup) items.
+     * This is the action collection of this class.
      */
-    Smb4KBrowserWidgetItem( QListView *parent, Smb4KWorkgroupItem *item );
+    KActionCollection *m_collection;
     /**
-     * The constructor for the workgroup member items.
+     * This function initializes the actions that are provided by this class.
      */
-    Smb4KBrowserWidgetItem( QListViewItem *parent, Smb4KHostItem *item );
+    void initActions();
     /**
-     * The constructor for the share items.
+     * This function inserts a host item into the browser window.
      */
-    Smb4KBrowserWidgetItem( QListViewItem *parent, Smb4KShareItem *item );
+    void insertItem( Smb4KHostItem *item );
     /**
-     * The destructor.
+     * The preview action.
      */
-    virtual ~Smb4KBrowserWidgetItem();
+    KAction *m_preview_action;
     /**
-     * Returns a pointer to the Smb4KWorkgoupItem object.
+     * The askpass action.
      */
-    Smb4KWorkgroupItem *getWorkgroupItem() const { return m_workgroup; }
+    KAction *m_askpass_action;
     /**
-     * Returns a pointer to the Smb4KHostItem object.
+     * The print action.
      */
-    Smb4KHostItem *getHostItem() const { return m_host; }
+    KAction *m_print_action;
     /**
-     * Returns a pointer to the Smb4KShareItem.
+     * The mount action.
      */
-    Smb4KShareItem *getShareItem() const { return m_share; }
+    KAction *m_mount_action;
     /**
-     * Tells the Smb4KBrowserWidgetItem if the share is already mounted or not and sets the 
-     * folder icon accordingly (open folder == mounted, closed folder == not mounted). 
-     * @param mounted Has to be TRUE if the share is mounted and FALSE otherwise.
-     * This function will only work with shares. Workgroup and host items are ignored.
+     * The bookmark action.
      */
-    void setMounted( bool mounted );
+    KAction *m_bookmark_action;
     /**
-     * Returns TRUE if the share is mounted and FALSE otherwise.
+     * The rescan action.
      */
-    bool isMounted() { return m_mounted; }
-     
-  protected:
+    KAction *m_rescan_action;
     /**
-     * Reimplemented from QListViewItem.
+     * The abort action.
      */
-    void paintCell( QPainter *p, const QColorGroup &cg, int column, int width, int align );
-  
-  private:
+    KAction *m_abort_action;
     /**
-     * The Smb4KWorkgroupItem object.
+     * The search action.
      */
-    Smb4KWorkgroupItem *m_workgroup;
-    /**
-     * The Smb4KHostItem object.
-     */
-    Smb4KHostItem *m_host;
-    /**
-     * The Smb4KShareItem object.
-     */
-    Smb4KShareItem *m_share;
-    /**
-     * Is TRUE if the share is mounted and FALSE otherwise.
-     * It will only be set, if Smb4KBrowserWidgetItem::depth() == 2,
-     * i. e. it is a share.
-     */
-    bool m_mounted;
+    KAction *m_search_action;
 };
 
 #endif
