@@ -36,10 +36,10 @@ Smb4KNetworkOptions::Smb4KNetworkOptions( QWidget *parent, const char *name ) :
   //
   QButtonGroup *browsebox = new QButtonGroup( 1, Qt::Horizontal, i18n( "Browse List" ), this );
 
-  m_useNMB = new QRadioButton( i18n( "Scan the network to retrieve the browse list." ), browsebox );
+  m_useNMB = new QRadioButton( i18n( "Scan the network to retrieve the browse list" ), browsebox );
   m_useNMB->setGeometry( QRect( 0, 0, m_useNMB->sizeHint().width(), m_useNMB->sizeHint().height() ) );
 
-  m_useHost = new QRadioButton( i18n( "Query a master browser to retrieve the browse list." ), browsebox );
+  m_useHost = new QRadioButton( i18n( "Query a master browser to retrieve the browse list" ), browsebox );
   m_useHost->setGeometry( QRect( 0, m_useNMB->frameGeometry().bottom()+5, m_useHost->sizeHint().width(), m_useHost->sizeHint().height() ) );
 
   QWidget *nameWidget = new QWidget( browsebox );
@@ -52,7 +52,7 @@ Smb4KNetworkOptions::Smb4KNetworkOptions( QWidget *parent, const char *name ) :
   m_hostName = new KLineEdit( nameWidget );
   m_hostName->setFixedWidth( 150 );
 
-  m_hostNeedsAuth = new QCheckBox( i18n( "This master browser needs authentication." ), nameWidget );
+  m_hostNeedsAuth = new QCheckBox( i18n( "This master browser needs authentication" ), nameWidget );
 
   QSpacerItem *spacer2 = new QSpacerItem( 10, 0, QSizePolicy::Expanding, QSizePolicy::Minimum );
 
@@ -63,7 +63,7 @@ Smb4KNetworkOptions::Smb4KNetworkOptions( QWidget *parent, const char *name ) :
   nameLayout->addItem( spacer2, 0, 3 );
   nameLayout->addMultiCellWidget( m_hostNeedsAuth, 1, 1, 1, 3, 0 );
 
-  m_mastersAuth = new QCheckBox( i18n( "Use authentication when querying the workgroup master browsers." ), browsebox );
+  m_mastersAuth = new QCheckBox( i18n( "Use authentication when querying the workgroup master browsers" ), browsebox );
 
   QWidget *winsWidget = new QWidget( browsebox );
   QGridLayout *winsLayout = new QGridLayout( winsWidget );
@@ -87,8 +87,8 @@ Smb4KNetworkOptions::Smb4KNetworkOptions( QWidget *parent, const char *name ) :
   description->setText( i18n( "Smb4K uses <i>nmblookup</i> by default to do network searches. This method is very reliable but fails sometimes if your network neighborhood is configured uncommonly. In this case you should try to use <i>smbclient</i>." ) );
   description->setTextFormat( Qt::RichText );
 
-  m_nmbSearch = new QRadioButton( i18n( "Use nmblookup. (recommended)" ), searchbox );
-  m_clientSearch = new QRadioButton( i18n( "Use smbclient." ), searchbox );
+  m_nmbSearch = new QRadioButton( i18n( "Use nmblookup (recommended)" ), searchbox );
+  m_clientSearch = new QRadioButton( i18n( "Use smbclient" ), searchbox );
   
   QSpacerItem *spacer5 = new QSpacerItem( 0, 0, QSizePolicy::Preferred, QSizePolicy::Expanding );
 
