@@ -29,6 +29,7 @@
 #include "smb4knetworktab.h"
 #include "../core/smb4kscanner.h"
 #include "../core/smb4knetworkitems.h"
+#include "../core/smb4kcore.h"
 #include "../smb4k.h"
 
 Smb4KNetworkTab::Smb4KNetworkTab( QWidget *parent, const char *name ) : QWidget( parent, name )
@@ -106,9 +107,12 @@ Smb4KNetworkTab::Smb4KNetworkTab( QWidget *parent, const char *name ) : QWidget(
   grid->addMultiCell( spacer4, 14, 14, 0, 4, 0 );
 
   // Connections:
-  connect( sapp->core()->scanner(),  SIGNAL( killed() )               ,       this, SLOT( slotKilled() ) );
-  connect( sapp->core()->scanner(),  SIGNAL( info( Smb4KHostItem * ) ),       this, SLOT( slotInfo( Smb4KHostItem * ) ) );
-  connect( sapp->core()->ipFinder(), SIGNAL( ip_address( Smb4KHostItem * ) ), this, SLOT( slotIPAddress( Smb4KHostItem * ) ) );
+  connect( smb4k_core->scanner(),  SIGNAL( killed() ),       
+           this,                   SLOT( slotKilled() ) );
+  connect( smb4k_core->scanner(),  SIGNAL( info( Smb4KHostItem * ) ),
+           this,                   SLOT( slotInfo( Smb4KHostItem * ) ) );
+  connect( smb4k_core->ipFinder(), SIGNAL( ip_address( Smb4KHostItem * ) ), 
+           this,                   SLOT( slotIPAddress( Smb4KHostItem * ) ) );
 }
 
 
@@ -171,7 +175,7 @@ void Smb4KNetworkTab::display( QListViewItem *item )
       m_workgroupLabel->setText( i18n( "Workgroup:" ) );
       m_workgroup->setText( m_current->text( Network ) );
 
-      Smb4KWorkgroupItem *i = sapp->core()->scanner()->getWorkgroup( m_current->text( Network ) );
+      Smb4KWorkgroupItem *i = smb4k_core->scanner()->getWorkgroup( m_current->text( Network ) );
       
       if ( !i->pseudo() )
       {
@@ -187,27 +191,32 @@ void Smb4KNetworkTab::display( QListViewItem *item )
     else if ( m_current->depth() == 1 )
     {
       bool search = false;
+      
       if ( oldItem->depth() == 0 )
       {
         search = true;
-        sapp->core()->scanner()->getInfo( m_current->parent()->text( Network ), m_current->text( Network ), m_current->text( IP ) );
+        smb4k_core->scanner()->getInfo( m_current->parent()->text( Network ), m_current->text( Network ), m_current->text( IP ) );
       }
-      else if ( ( oldItem->depth() == 1 && oldItem->text( Network ) != m_current->text( Network ) ) || m_hostLabel->text().isEmpty() )
+      else if ( (oldItem->depth() == 1 && 
+                 QString::compare( oldItem->text( Network ), m_current->text( Network ) ) != 0) ||
+                m_hostLabel->text().isEmpty() )
       {
         search = true;
-        sapp->core()->scanner()->getInfo( m_current->parent()->text( Network ), m_current->text( Network ), m_current->text( IP ) );
+        smb4k_core->scanner()->getInfo( m_current->parent()->text( Network ), m_current->text( Network ), m_current->text( IP ) );
       }
-      else if ( ( oldItem->depth() == 2  && oldItem->parent()->text( Network ) != m_current->text( Network ) ) || m_hostLabel->text().isEmpty() )
+      else if ( (oldItem->depth() == 2  && 
+                 QString::compare( oldItem->parent()->text( Network ), m_current->text( Network ) ) != 0) ||
+                m_hostLabel->text().isEmpty() )
       {
         search = true;
-        sapp->core()->scanner()->getInfo( m_current->parent()->text( Network ), m_current->text( Network ), m_current->text( IP ) );
+        smb4k_core->scanner()->getInfo( m_current->parent()->text( Network ), m_current->text( Network ), m_current->text( IP ) );
       }
 
       m_workgroupLabel->setText( i18n( "Workgroup:" ) );
 
       m_workgroup->setText( m_current->parent()->text( Network ) );
       
-      Smb4KWorkgroupItem *i = sapp->core()->scanner()->getWorkgroup( m_current->parent()->text( Network ) );
+      Smb4KWorkgroupItem *i = smb4k_core->scanner()->getWorkgroup( m_current->parent()->text( Network ) );
       
       if ( !i->pseudo() )
       {
@@ -248,24 +257,28 @@ void Smb4KNetworkTab::display( QListViewItem *item )
       if ( oldItem->depth() == 0 )
       {
         search = true;
-        sapp->core()->scanner()->getInfo( m_current->parent()->parent()->text( Network ), m_current->parent()->text( Network ), m_current->parent()->text( IP ) );
+        smb4k_core->scanner()->getInfo( m_current->parent()->parent()->text( Network ), m_current->parent()->text( Network ), m_current->parent()->text( IP ) );
       }
-      else if ( ( oldItem->depth() == 1 && oldItem->text( Network ) != m_current->parent()->text( Network ) ) || m_hostLabel->text().isEmpty() )
+      else if ( (oldItem->depth() == 1 && 
+                 QString::compare( oldItem->text( Network ), m_current->parent()->text( Network ) ) != 0) ||
+                m_hostLabel->text().isEmpty() )
       {
         search = true;
-        sapp->core()->scanner()->getInfo( m_current->parent()->parent()->text( Network ), m_current->parent()->text( Network ), m_current->parent()->text( IP ) );
+        smb4k_core->scanner()->getInfo( m_current->parent()->parent()->text( Network ), m_current->parent()->text( Network ), m_current->parent()->text( IP ) );
       }
-      else if ( ( oldItem->depth() == 2 && oldItem->parent()->text( Network ) != m_current->parent()->text( Network ) ) || m_hostLabel->text().isEmpty() )
+      else if ( (oldItem->depth() == 2 && 
+                 QString::compare( oldItem->parent()->text( Network ), m_current->parent()->text( Network ) ) != 0) || 
+                m_hostLabel->text().isEmpty() )
       {
         search = true;
-        sapp->core()->scanner()->getInfo( m_current->parent()->parent()->text( Network ), m_current->parent()->text( Network ), m_current->parent()->text( IP ) );
+        smb4k_core->scanner()->getInfo( m_current->parent()->parent()->text( Network ), m_current->parent()->text( Network ), m_current->parent()->text( IP ) );
       }
 
       m_workgroupLabel->setText( i18n( "Workgroup:" ) );
 
       m_workgroup->setText( m_current->parent()->parent()->text( Network ) );
 
-      Smb4KWorkgroupItem *i = sapp->core()->scanner()->getWorkgroup( m_current->parent()->parent()->text( Network ) );
+      Smb4KWorkgroupItem *i = smb4k_core->scanner()->getWorkgroup( m_current->parent()->parent()->text( Network ) );
       
       if ( !i->pseudo() )
       {
@@ -329,17 +342,28 @@ void Smb4KNetworkTab::slotInfo( Smb4KHostItem *host )
 {
   QString newOS;
   QString newServer;
+  
   if ( host->osString().contains( "Unix" ) != 0 )
+  {
     newOS = QString( "Linux/" ).append( host->osString() );
+  }
   else if ( host->osString().isEmpty() )
+  {
     newOS = i18n( "Unknown" );
+  }
   else
+  {
     newOS = host->osString();
+  }
   
   if ( host->serverString().isEmpty() )
+  {
     newServer = i18n( "Unknown" );
+  }
   else
+  {
     newServer = host->serverString();
+  }
 
   // Now display everything:
   if ( m_current->depth() == 1 )
@@ -378,14 +402,26 @@ void Smb4KNetworkTab::slotIPAddress( Smb4KHostItem *item )
     host = m_host->text().stripWhiteSpace();
   }
   
-  if ( item->name() == host
-       && item->workgroup() == m_workgroup->text().stripWhiteSpace()
-       && !item->ip().stripWhiteSpace().isEmpty()
-       && m_ip->text().stripWhiteSpace() == i18n( "Unknown" ) )
+  if ( QString::compare( item->name(), host ) == 0 && 
+       QString::compare( item->workgroup(), m_workgroup->text().stripWhiteSpace() ) == 0 &&
+       !item->ip().stripWhiteSpace().isEmpty() &&
+       QString::compare( m_ip->text().stripWhiteSpace(), i18n( "Unknown" ) ) == 0 )
   {
     m_ip->setText( item->ip() );
   }
 }
 
 
+void Smb4KNetworkTab::slotGetListViewItem( QListViewItem *item )
+{
+  display( item );
+}
+
+
+void Smb4KNetworkTab::slotClearWidget()
+{
+  clear( 0 );
+}
+
+
 #include "smb4knetworktab.moc"
