@@ -73,13 +73,22 @@ class Smb4KNetworkTab : public QWidget
      */
     void slotKilled();
     /**
-     * This slot takes the Smb4KHostItem that is emitted by Smb4KIPFinder and compares it
-     * with the host that's displayed. If the host name matches and the IP address is not
+     * This slot takes a reference to a Smb4KHostItem and compares its contents with 
+     * the host that's displayed. If the host name matches and the IP address is not
      * displayed, it will be inserted in the widget.
      *
      * @param item  The Smb4KHostItem emitted by Smb4KIPFinder.
      */
     void slotIPAddress( Smb4KHostItem *item );
+    /**
+     * This slot takes a QListViewItem (from the browser widget) and invokes the display()
+     * funtion.
+     */
+    void slotGetListViewItem( QListViewItem * );
+    /**
+     * This slot clears the whole widget.
+     */
+    void slotClearWidget();
 
   private:
     enum Entries{ Network = 0, Type = 1, IP = 2, Comment = 3 };
