@@ -25,7 +25,6 @@
 // KDE includes
 #include <kdialogbase.h>
 #include <kurlrequester.h>
-#include <kconfig.h>
 
 // application specific includes
 #include "smb4kshareoptions.h"
@@ -41,7 +40,7 @@ class Smb4KOptionsDlg : public KDialogBase
   Q_OBJECT
 
   friend class Smb4KApp;
-  
+
   public:
     /**
      * The constructor
@@ -51,7 +50,7 @@ class Smb4KOptionsDlg : public KDialogBase
      * The destructor
      */
     ~Smb4KOptionsDlg();
-    
+
   signals:
     /**
      * This signal informs the rest of the program, that the options have been
@@ -95,12 +94,11 @@ class Smb4KOptionsDlg : public KDialogBase
      * Enables/disables widgets in the Samba according to the choice
      * of the filesystem (SMBFS/CIFS).
      *
-     * This slot is connected to the button that represents the SMB
-     * file system.
+     * This slot is connected to the combo box that stores the file systems.
      *
-     * @param on  Describes the toggle state of the SMBFS button.
+     * @param filesystem       the name of the filesystem that should be used
      */
-    void slotSambaFileSystem( bool on );
+    void slotSambaFileSystem( const QString &filesystem );
     /**
      * Enables/disables buttons on the appearance page according to the
      * toggle state of the "Show hidden shares." button.
@@ -120,12 +118,17 @@ class Smb4KOptionsDlg : public KDialogBase
      * according to the choice the user made.
      */
     void slotRemoveSuperUserEntries();
+    /**
+     * This slot manages the toggling of the KWallet support button in the
+     * Authentication tab.
+     */
+    void slotKWalletButtonState( int state );
+    /**
+     * This slot manages the toggling of the default authentication button.
+     */
+    void slotDefaultAuthButtonState( int state );
 
   private:
-    /**
-     * The KConfig object.
-     */
-    KConfig *m_config;
     /**
      * Set up the browse options page.
      */
@@ -170,7 +173,7 @@ class Smb4KOptionsDlg : public KDialogBase
      * The Samba page object
      */
     Smb4KSambaOptions *m_sambaPage;
-    
+
     /**
      * Sets up the misc options page.
      */
@@ -179,7 +182,7 @@ class Smb4KOptionsDlg : public KDialogBase
      * The misc options page object
      */
     Smb4KSuperUserOptions *m_superPage;
-    
+
     /**
      * This function checks whether all necessary specifications
      * have been provided before applying any changes.
@@ -192,7 +195,7 @@ class Smb4KOptionsDlg : public KDialogBase
     /**
      * The enumeration for the pages.
      */
-    enum Pages{ Appearance = 0, Network = 1, Shares = 2, Authentication = 3, Samba = 4, Misc = 5 };
+    enum Pages{ Appearance = 0, Network = 1, Shares = 2, Authentication = 3, Samba = 4, SuperUser = 5 };
 };
 
 #endif
