@@ -20,7 +20,7 @@
 #include <qtooltip.h>
 #include <qiconset.h>
 #include <qregexp.h>
- 
+
 // KDE includes
 #include <klocale.h>
 #include <kapplication.h>
@@ -29,14 +29,13 @@
 // application specific includes
 #include "smb4kpreviewdialog.h"
 #include "../smb4k.h"
+#include "../core/smb4kcore.h"
 
 
 Smb4KPreviewDialog::Smb4KPreviewDialog( const QString &workgroup, const QString &host, const QString &ip,
 const QString &share, QWidget *parent, const char *name, bool modal )
 : KDialogBase( Plain, i18n( "Preview" ), Close, Close, parent, name, modal, true )
 {
-  m_config = kapp->config();
-
   m_workgroup = workgroup;
   m_host = host;
   m_share = share;
@@ -51,14 +50,14 @@ const QString &share, QWidget *parent, const char *name, bool modal )
   setMinimumSize( sizeHint() );
   setWFlags( Qt::WDestructiveClose );
 
-  connect( this, SIGNAL( finished() ), SLOT( slotFinished() ) );
-  connect( m_view, SIGNAL( executed( QIconViewItem * ) ), SLOT( slotItemExecuted( QIconViewItem * ) ) );
-  connect( m_toolbar, SIGNAL( clicked( int ) ), SLOT( slotButtonClicked( int ) ) );
-  connect( m_combo, SIGNAL( activated( const QString & ) ), SLOT( slotItemActivated( const QString & ) ) );
-  
-  connect( sapp->core()->scanner(), SIGNAL( previewResult( const QValueList<Smb4KPreviewItem *> & ) ), this, SLOT( slotReceivedData( const QValueList<Smb4KPreviewItem *> & ) ) );
-  
-  sapp->core()->scanner()->getPreview( workgroup, host, ip, share, QString::null );
+  connect( this,                  SIGNAL( finished() ), this,                   SLOT( slotFinished() ) );
+  connect( m_view,                SIGNAL( executed( QIconViewItem * ) ), this,  SLOT( slotItemExecuted( QIconViewItem * ) ) );
+  connect( m_toolbar,             SIGNAL( clicked( int ) ), this,               SLOT( slotButtonClicked( int ) ) );
+  connect( m_combo,               SIGNAL( activated( const QString & ) ), this, SLOT( slotItemActivated( const QString & ) ) );
+
+  connect( smb4k_core->scanner(), SIGNAL( previewResult( const QValueList<Smb4KPreviewItem *> & ) ), this, SLOT( slotReceivedData( const QValueList<Smb4KPreviewItem *> & ) ) );
+
+  smb4k_core->scanner()->getPreview( workgroup, host, ip, share, QString::null );
 }
 
 
@@ -98,15 +97,15 @@ void Smb4KPreviewDialog::setupView()
 
 void Smb4KPreviewDialog::saveOptions()
 {
-  m_config->setGroup( "General Options" );
-  m_config->writeEntry( "Preview Dialog Geometry", size() );
+  config()->setGroup( "General Options" );
+  config()->writeEntry( "Preview Dialog Geometry", size() );
 }
 
 
 void Smb4KPreviewDialog::readOptions()
 {
-  m_config->setGroup( "General Options" );
-  setInitialSize( m_config->readSizeEntry( "Preview Dialog Geometry", 0L ) );
+  config()->setGroup( "General Options" );
+  setInitialSize( config()->readSizeEntry( "Preview Dialog Geometry", 0L ) );
 }
 
 
@@ -150,15 +149,16 @@ void Smb4KPreviewDialog::slotReceivedData( const QValueList<Smb4KPreviewItem *>
       int index = 0;
       int pos = 0;
       bool exists = false;
+
       while ( index < m_combo->count() )
       {
-        if ( m_combo->text( index ).stripWhiteSpace() == item.stripWhiteSpace() )
+        if ( QString::compare( m_combo->text( index ).stripWhiteSpace(), item.stripWhiteSpace() ) == 0 )
         {
           pos = index;
           exists = true;
           break;
         }
-        else if ( m_combo->text( index ).stripWhiteSpace() == m_address )
+        else if ( QString::compare( m_combo->text( index ).stripWhiteSpace(), m_address ) == 0 )
         {
           pos = index;
           exists = true;
@@ -166,6 +166,7 @@ void Smb4KPreviewDialog::slotReceivedData( const QValueList<Smb4KPreviewItem *>
         }
         index++;
       }
+
       if ( !exists )
       {
         m_combo->insertItem( item, 0 );
@@ -174,19 +175,19 @@ void Smb4KPreviewDialog::slotReceivedData( const QValueList<Smb4KPreviewItem *>
       else
         m_combo->setCurrentItem( pos );
     }
-  
+
     for ( QValueList<Smb4KPreviewItem *>::ConstIterator it = list.begin(); it != list.end(); ++it )
     {
       if ( (*it)->isFile() )
       {
-        QIconViewItem *view_item = new QIconViewItem( m_view, (*it)->name(), SmallIcon( "unknown" ) );
+        QIconViewItem *view_item = new QIconViewItem( m_view, (*it)->name(), SmallIcon( "misc" ) );
         view_item->setKey( QString( "1%1" ).arg( (*it)->name() ) );
       }
       else
       {
-        if ( (*it)->name() != "." && (*it)->name() != ".." )
+        if ( QString::compare( (*it)->name(), "." ) != 0 && QString::compare( (*it)->name(), ".." ) !=0 )
         {
-          QIconViewItem *view_item = new QIconViewItem( m_view, (*it)->name(), SmallIcon( "folder_green" ) );
+          QIconViewItem *view_item = new QIconViewItem( m_view, (*it)->name(), SmallIcon( "folder" ) );
           view_item->setKey( QString( "0%1" ).arg( (*it)->name() ) );
         }
       }
@@ -195,9 +196,13 @@ void Smb4KPreviewDialog::slotReceivedData( const QValueList<Smb4KPreviewItem *>
   else
   {
     if ( m_path.contains( "/" ) == 1 )
+    {
       m_path = QString::null;
+    }
     else
+    {
       m_path = m_path.section( "/", 0, -2 ).stripWhiteSpace();
+    }
   }
 }
 
@@ -208,8 +213,8 @@ void Smb4KPreviewDialog::slotItemExecuted( QIconViewItem *item )
   {
     QString tmp = item->text();
     m_path.append( tmp ).append( "/" );
-    
-    sapp->core()->scanner()->getPreview( m_workgroup, m_host, m_ip, m_share, m_path );
+
+    smb4k_core->scanner()->getPreview( m_workgroup, m_host, m_ip, m_share, m_path );
   }
 }
 
@@ -219,11 +224,15 @@ void Smb4KPreviewDialog::slotButtonClicked( int id )
   if ( id == Up && !m_path.isEmpty() )
   {
     if ( m_path.contains( "/" ) > 1 )
+    {
       m_path = m_path.section( "/", 0, -3 ).append( "/" );
+    }
     else if ( m_path.contains( "/", true ) == 1 )
+    {
       m_path = QString::null;
+    }
 
-    sapp->core()->scanner()->getPreview( m_workgroup, m_host, m_ip, m_share, m_path );
+    smb4k_core->scanner()->getPreview( m_workgroup, m_host, m_ip, m_share, m_path );
   }
 }
 
@@ -231,10 +240,10 @@ void Smb4KPreviewDialog::slotButtonClicked( int id )
 void Smb4KPreviewDialog::slotItemActivated( const QString &item )
 {
   // First we have to strip the address:
-  QString path = item.section( m_address, 1, 1 ).stripWhiteSpace(); 
-  
-  sapp->core()->scanner()->getPreview( m_workgroup, m_host, m_ip, m_share, path );
-  
+  QString path = item.section( m_address, 1, 1 ).stripWhiteSpace();
+
+  smb4k_core->scanner()->getPreview( m_workgroup, m_host, m_ip, m_share, path );
+
   m_path = path;
 }
 
