@@ -28,6 +28,7 @@
 #include "smb4kprintdialog.h"
 #include "../smb4k.h"
 #include "../core/smb4kprintinfo.h"
+#include "../core/smb4kcore.h"
 
 Smb4KPrintDialog::Smb4KPrintDialog( const QString &workgroup, const QString &host, const QString &ip, const QString &printer, const QString &comment, QWidget *parent, const char *name ) 
 : KDialogBase( Plain, i18n( "Print File" ), Ok|Cancel, Ok, parent, name, false, true ), m_workgroup( workgroup ), m_host( host ), m_ip( ip ), m_printer( printer )
@@ -111,13 +112,17 @@ void Smb4KPrintDialog::slotOk()
 {
   if ( !m_input->url().stripWhiteSpace().isEmpty() )
   {    
-    if ( sapp->core()->print()->init( new Smb4KPrintInfo( m_workgroup, m_host, m_ip, m_printer, m_input->url().stripWhiteSpace(), m_copies->value() ) ) )
+    if ( smb4k_core->print()->init( new Smb4KPrintInfo( m_workgroup, m_host, m_ip, m_printer, m_input->url().stripWhiteSpace(), m_copies->value() ) ) )
+    {
       accept();
+    }
       
 //     delete info;
   }
   else
+  {
     KMessageBox::error( this, i18n( "You haven't specified a file." ) );
+  }
 }
 
 
