@@ -57,7 +57,7 @@ class Smb4KSambaOptions : public QTabWidget
     ~Smb4KSambaOptions();
 
   private:
-    /** 
+    /**
      * This line edit is for the NetBIOS name.
      */
     KLineEdit *m_netbios;
@@ -84,39 +84,67 @@ class Smb4KSambaOptions : public QTabWidget
      * Holds the directory mask.
      */
     KLineEdit *m_dmask;
-    QRadioButton *m_ro;
-    QRadioButton *m_rw;
+    /**
+     * The combo box where the user can choose whether the 
+     * shares should be mounted read/write or read only.
+     */
+    KComboBox *m_read_mode;
     KComboBox *m_charset;
     KComboBox *m_codepage;
     KLineEdit *m_sockopt;
     KLineEdit *m_scope;
     KIntNumInput *m_ttl;
+    /**
+     * Determines whether Kerberos should be used.
+     */
     QCheckBox *m_krb;
     QCheckBox *m_unicode;
     QCheckBox *m_lfs;
     KLineEdit *m_resolve;
     KIntNumInput *m_buffer;
     QCheckBox *m_udp;
+    /**
+     * Holds the domain string.
+     */
     KLineEdit *m_domain;
     KLineEdit *m_broadcast;
     /**
-     * The radio button for the smbfs file system.
+     * The combo box where the user can choose the file system that
+     * should be used for mounting.
      */
-    QRadioButton *m_smbfs;
+    KComboBox *m_filesystem;
     /**
-     * The radio button for the cifs file system.
-     */
-    QRadioButton *m_cifs;
-    /**
-     * This check box determines whether the user wants to use the 
+     * This check box determines whether the user wants to use the
      * default network read size. (CIFS only).
      */
     QCheckBox *m_rsize;
     /**
-     * This check box determines whether the user wants to use the 
+     * This check box determines whether the user wants to use the
      * default network write size. (CIFS only).
      */
     QCheckBox *m_wsize;
+    /**
+     * This button deterimes that the protocol for the net command
+     * should be auto-detected.
+     */
+    QRadioButton *m_net_auto;
+    /**
+     * net command should use ADS protocol.
+     */
+    QRadioButton *m_net_ads;
+    /**
+     * net command should use RPC protocol.
+     */
+    QRadioButton *m_net_rpc;
+    /**
+     * net command should use RAP protocol.
+     */
+    QRadioButton *m_net_rap;
+    /**
+     * If this button is checked, the '-P' (authenticate as machine account)
+     * option should be added to the net command.
+     */
+    QCheckBox *m_net_machine_account;
 };
 
 #endif
