@@ -28,8 +28,8 @@
 
 // application specific includes
 #include "smb4ksearchtab.h"
-#include "../smb4k.h"
 #include "../core/smb4knetworkitems.h"
+#include "../core/smb4kcore.h"
 
 
 Smb4KSearchTab::Smb4KSearchTab( QWidget *parent, const char *name ) : QWidget( parent, name )
@@ -70,7 +70,7 @@ Smb4KSearchTab::Smb4KSearchTab( QWidget *parent, const char *name ) : QWidget( p
   connect( m_input,          SIGNAL( returnPressed() ), this, SLOT( slotSearchClicked() ) );
   
   // External connections
-  connect( sapp->core()->scanner(), SIGNAL( searchResult( Smb4KHostItem * ) ), this, SLOT( slotReceivedSearchResult( Smb4KHostItem * ) ) );
+  connect( smb4k_core->scanner(), SIGNAL( searchResult( Smb4KHostItem * ) ), this, SLOT( slotReceivedSearchResult( Smb4KHostItem * ) ) );
 //  connect( m_window, SIGNAL( executed( QListBoxItem * ) ), this, SLOT( slotItemExecuted( QListBoxItem * ) ) );
 
   QToolTip::add( m_window, i18n( "Search results" ) );
@@ -91,7 +91,7 @@ void Smb4KSearchTab::slotSearchClicked()
 {
   if ( !m_input->currentText().stripWhiteSpace().isEmpty() )
   {
-    sapp->core()->scanner()->makeSearch( m_input->currentText().stripWhiteSpace() );
+    smb4k_core->scanner()->makeSearch( m_input->currentText().stripWhiteSpace() );
     m_host = m_input->currentText().upper();
     m_input->clearEdit();
   }
@@ -108,7 +108,7 @@ void Smb4KSearchTab::slotAddClicked()
     
     if ( !workgroup.isEmpty() )
     {
-      sapp->networkView()->insertItem( new Smb4KHostItem( workgroup, host, QString::null, ip ) );
+      emit searchResult( new Smb4KHostItem( workgroup, host, QString::null, ip ) );
     }
     else
     {
@@ -127,13 +127,11 @@ void Smb4KSearchTab::slotClearAllClicked()
 
 void Smb4KSearchTab::slotReceivedSearchResult( Smb4KHostItem *item )
 {
-  // Did the search fail?
   if ( item->workgroup().isEmpty() && item->name().isEmpty() && item->ip().isEmpty() )
   {
     QString entry = i18n( "The search for %1 failed." ).arg( m_host );
     m_window->insertItem( SmallIcon( "no" ), entry, 0 );
   }
-  // If the search did not fail:
   else
   {
     QString entry( item->name() );
