@@ -52,6 +52,14 @@ class Smb4KSearchTab : public QWidget
      * The destructor.
      */
     ~Smb4KSearchTab();
+    
+  signals:
+    /**
+     * This signal emits the highlighted search result.
+     *
+     * @param item        the search result
+     */
+    void searchResult( Smb4KHostItem *item );
 
   protected slots:
     /** 
