@@ -42,14 +42,14 @@ Smb4KShareOptions::Smb4KShareOptions( QWidget *parent, const char *name ) : QWid
   defaultPathLabel->setTextFormat( RichText );
   m_defaultPath = new KURLRequester( QString::null, dirBox );
   m_defaultPath->setMode( KFile::Directory );
-  m_lowercase = new QCheckBox( i18n( "Force generated subdirectories to be lower case." ), dirBox );
+  m_lowercase = new QCheckBox( i18n( "Force generated subdirectories to be lower case" ), dirBox );
 
   QButtonGroup *mountBox = new QButtonGroup( i18n( "Mounting and Unmounting" ), this );
-  m_unmountAll = new QCheckBox( i18n( "Unmount all of %1's shares on exit." ).arg( getenv( "USER" ) ), mountBox );
+  m_unmountAll = new QCheckBox( i18n( "Unmount all shares of user %1 on exit" ).arg( getenv( "USER" ) ), mountBox );
   m_unmountAll->setGeometry( 10, 25, m_unmountAll->sizeHint().width(), m_unmountAll->sizeHint().height() );
-  m_mountRecent = new QCheckBox( i18n( "Remount recently used shares on program start." ), mountBox );
+  m_mountRecent = new QCheckBox( i18n( "Remount recently used shares on program start" ), mountBox );
   m_mountRecent->setGeometry( 10, m_unmountAll->frameGeometry().bottom()+5, m_mountRecent->sizeHint().width(), m_mountRecent->sizeHint().height() );
-  m_allowUnmountForeign = new QCheckBox( i18n( "Allow the unmounting of shares that are owned by other users." ), mountBox );
+  m_allowUnmountForeign = new QCheckBox( i18n( "Allow the unmounting of shares that are owned by other users" ), mountBox );
   m_allowUnmountForeign->setGeometry( 10, m_mountRecent->frameGeometry().bottom()+5, m_allowUnmountForeign->sizeHint().width(), m_allowUnmountForeign->sizeHint().height() );
 
   QSpacerItem *spacer2 = new QSpacerItem( 0, 0, QSizePolicy::Preferred, QSizePolicy::Expanding );
