@@ -30,8 +30,8 @@
 
 // application specific includes
 #include "smb4ksharetab.h"
-#include "../smb4k.h"
 #include "../core/smb4kuser.h"
+#include "../core/smb4kcore.h"
 
 Smb4KShareTab::Smb4KShareTab( QWidget *parent, const char *name ) : QWidget( parent, name )
 {
@@ -112,8 +112,8 @@ Smb4KShareTab::Smb4KShareTab( QWidget *parent, const char *name ) : QWidget( par
   grid->addMultiCellWidget( m_contents, 14, 14, 2, 4, 0 );
   grid->addMultiCell( spacer4, 15, 15, 0, 4, 0 );
   
-  connect( sapp->core(), SIGNAL( usage( const QString &, double, double, double, double, int, int ) ), 
-                   this, SLOT( slotUsage( const QString &, double, double, double, double, int, int ) ) );
+  connect( smb4k_core, SIGNAL( usage( const QString &, double, double, double, double, int, int ) ), 
+           this, SLOT( slotUsage( const QString &, double, double, double, double, int, int ) ) );
 }
 
 
@@ -151,7 +151,7 @@ void Smb4KShareTab::clear()
 
 void Smb4KShareTab::slotUsage( const QString &mountpoint, double total, double used, double free, double percent, int dirs, int files )
 {
-  Smb4KShare *share = sapp->core()->mounter()->findShareByPath( mountpoint );
+  Smb4KShare *share = smb4k_core->mounter()->findShareByPath( mountpoint );
   
   if ( share && !share->isBroken() )
   {
@@ -160,7 +160,7 @@ void Smb4KShareTab::slotUsage( const QString &mountpoint, double total, double u
     m_mountpointLabel->setText( i18n( "Mount Point:" ) );
     m_userLabel->setText( i18n( "User:" ) );
     
-    if ( share->getFilesystem() == "smbfs" )
+    if ( QString::compare( share->getFilesystem(), "smbfs" ) == 0 )
     {
       m_groupLabel->setText( i18n( "Group:" ) );
       m_user->setText( QString( "%1   (%2)" ).arg( share->getUser() ).arg( share->getUID() ) );
@@ -295,4 +295,10 @@ void Smb4KShareTab::slotUsage( const QString &mountpoint, double total, double u
 }
 
 
+void Smb4KShareTab::slotClearWidget()
+{
+  clear();
+}
+
+
 #include "smb4ksharetab.moc"
