@@ -71,7 +71,11 @@ class Smb4KShareTab : public QWidget
      *
      * @param files         The number of files present in the root of this share.
      */
-    void slotUsage( const QString &mountpoint, double total, double used, double free, double percent, int dirs, int files );    
+    void slotUsage( const QString &mountpoint, double total, double used, double free, double percent, int dirs, int files );
+    /**
+     * This slot is called when the widget has to be cleared.
+     */
+    void slotClearWidget();
     
 
   private:
