@@ -26,7 +26,7 @@
 #include <kapplication.h>
 #include <kactionclasses.h>
 #include <kpopupmenu.h>
-#include <kaction.h>
+#include <kiconloader.h>
 
 // system includes
 #include <unistd.h>
@@ -34,14 +34,12 @@
 
 // application specific includes
 #include "smb4ksharewidget.h"
-#include "../smb4k.h"
 #include "smb4kmountdialog.h"
+#include "../core/smb4kcore.h"
 
 
 Smb4KShareWidget::Smb4KShareWidget( QWidget *parent, const char *name ) : KIconView( parent, name )
 {
-  m_config = kapp->config();
-
   setFrameShape( KIconView::PopupPanel );
   setFrameShadow( KIconView::Sunken );
   setSelectionMode( KIconView::Single );
@@ -49,12 +47,16 @@ Smb4KShareWidget::Smb4KShareWidget( QWidget *parent, const char *name ) : KIconV
   setShowToolTips( true );
   setAutoArrange( true );
   setSorting( true, true );
-  
+
+  m_collection = new KActionCollection( this, "SharesView_ActionCollection", KGlobal::instance() );
+
+  initActions();
+
   // Internal connections
-  connect( this, SIGNAL( mouseButtonPressed( int, QIconViewItem *, const QPoint & ) ), this, SLOT( slotButtonPressed( int, QIconViewItem *, const QPoint & ) ) );
-  connect( this, SIGNAL( executed( QIconViewItem * ) ),                                this, SLOT( slotOpenFilemanager() ) );
-  connect( this, SIGNAL( selectionChanged( QIconViewItem * ) ),                        this, SLOT( slotSelectionChanged( QIconViewItem * ) ) );
-  connect( sapp->core()->mounter(), SIGNAL( importedShares() ),                        this, SLOT( slotMountedShares() ) );
+  connect( this,                  SIGNAL( mouseButtonPressed( int, QIconViewItem *, const QPoint & ) ), this, SLOT( slotButtonPressed( int, QIconViewItem *, const QPoint & ) ) );
+  connect( this,                  SIGNAL( executed( QIconViewItem * ) ),                                this, SLOT( slotOpenFilemanager() ) );
+  connect( this,                  SIGNAL( selectionChanged( QIconViewItem * ) ),                        this, SLOT( slotSelectionChanged( QIconViewItem * ) ) );
+  connect( smb4k_core->mounter(), SIGNAL( updated() ),                                           this, SLOT( slotMountedShares() ) );
 }
 
 
@@ -62,24 +64,53 @@ Smb4KShareWidget::~Smb4KShareWidget()
 {
 }
 
+
+/****************************************************************************
+   Initialize the actions needed by this class.
+****************************************************************************/
+
+void Smb4KShareWidget::initActions()
+{
+  m_unmount_action = new KAction( i18n( "&Unmount" ), "hdd_unmount", CTRL+Key_U, this,            SLOT( slotUnmountShare() ), m_collection, "shares_unmount_share" );
+  m_unmount_action->setGroup( "ShareWidget" );
+  m_unmount_action->setEnabled( false );
+
+  m_force_action = new KAction( i18n( "&Force Unmounting" ), "hdd_unmount", CTRL+Key_F, this,     SLOT( slotForceUnmountShare() ), m_collection, "shares_force_unmount" );
+  m_force_action->setGroup( "ShareWidget" );
+  m_force_action->setEnabled( false );
+
+  m_unmount_all_action = new KAction( i18n( "U&nmount All" ), "gear", CTRL+Key_N, this,           SLOT( slotUnmountAllShares() ), m_collection, "shares_unmount_all" );
+  m_unmount_all_action->setGroup( "ShareWidget" );
+  m_unmount_all_action->setEnabled( false );
+
+  m_manual_action = new KAction( i18n( "M&ount Manually" ), "connect_creating", CTRL+Key_O, this, SLOT( slotManualMount() ), m_collection, "shares_manual_mount" );
+  m_manual_action->setGroup( "ShareWidget" );
+  m_manual_action->setEnabled( true );
+
+  m_filemanager_action = new KAction( i18n( "&Konqueror" ), "kfm_home", CTRL+Key_K, this,         SLOT( slotOpenFilemanager() ), m_collection, "shares_start_filemanager" );
+  m_filemanager_action->setGroup( "ShareWidget" );
+  m_filemanager_action->setEnabled( false );
+}
+
+
 /****************************************************************************
    Reads the options for the share view widget.
 ****************************************************************************/
 
 void Smb4KShareWidget::readOptions()
-{  
+{
   // Which appearance does the user want?
-  m_config->setGroup( "Appearance" );
-  m_display = m_config->readEntry( "Show Shares", "icons" );
-  
-  if ( m_display == "icons" )
+  config()->setGroup( "Appearance" );
+  m_display = config()->readEntry( "Show Shares", "icons" );
+
+  if ( QString::compare( m_display, "icons" ) == 0 )
   {
     setItemTextPos( KIconView::Bottom );
     setMaxItemWidth( 150 );
     setArrangement( KIconView::LeftToRight );
     setWordWrapIconText( true );
   }
-  else if ( m_display == "list" )
+  else if ( QString::compare( m_display, "list" ) == 0 )
   {
     setItemTextPos( KIconView::Right );
     setMaxItemWidth( 300 );
@@ -87,24 +118,24 @@ void Smb4KShareWidget::readOptions()
     setWordWrapIconText( false );
   }
 
-  m_mountpoint = m_config->readBoolEntry( "Show Mount Point", false );
+  m_mountpoint = config()->readBoolEntry( "Show Mount Point", false );
 
   // Should all share be shown, that were mounted on the system?
-  m_showExternal = m_config->readBoolEntry( "Show All Shares", false );
-  
+  m_showExternal = config()->readBoolEntry( "Show All Shares", false );
+
   if ( count() != 0 )
   {
     for ( QIconViewItem *item = this->firstItem(); item; item = item->nextItem() )
     {
-      if ( m_display == "icons" )
+      if ( QString::compare( m_display, "icons" ) == 0 )
       {
         item->setPixmap( DesktopIcon( "hdd_mount" ) );
       }
-      else if ( m_display == "list" )
+      else if ( QString::compare( m_display, "list" ) == 0 )
       {
         item->setPixmap( SmallIcon( "hdd_mount" ) );
       }
-      
+
       if ( m_mountpoint )
       {
         item->setText( ((Smb4KShareWidgetItem *)item)->mountpoint() );
@@ -115,20 +146,20 @@ void Smb4KShareWidget::readOptions()
       }
     }
   }
-  
+
   slotMountedShares();
-  
+
   adjustItems();
 
   // Mount options.
-  m_config->setGroup( "Programs" );
-  QString super = m_config->readPathEntry( "super" );
-  QString sudo = m_config->readPathEntry( "sudo" );
-  
-  m_config->setGroup( "Super User Privileges" );
+  config()->setGroup( "Programs" );
+  QString super = config()->readPathEntry( "super" );
+  QString sudo = config()->readPathEntry( "sudo" );
+
+  config()->setGroup( "Super User Privileges" );
   if ( !super.isEmpty() || !sudo.isEmpty() )
   {
-    m_forcedUnmount = m_config->readBoolEntry( "Force Unmount", false );
+    m_forcedUnmount = config()->readBoolEntry( "Force Unmount", false );
   }
   else
   {
@@ -155,44 +186,45 @@ void Smb4KShareWidget::slotButtonPressed( int button, QIconViewItem *item, const
     // Enable the actions:
     if ( m_forcedUnmount )
     {
-      sapp->sharesForceUnmount->setEnabled( true );
+      m_force_action->setEnabled( true );
     }
-    
+
     if ( !i->isBroken() )
     {
-      sapp->sharesStartFilemanager->setEnabled( true );
-      sapp->core()->setShareForUsageInfo( i->shareObject() );
+      m_filemanager_action->setEnabled( true );
+      smb4k_core->setShareForUsageInfo( i->shareObject() );
     }
     else
     {
-      sapp->sharesStartFilemanager->setEnabled( false );
-      sapp->core()->setShareForUsageInfo( NULL );
+      m_filemanager_action->setEnabled( false );
+      smb4k_core->setShareForUsageInfo( NULL );
     }
-      
-    sapp->sharesUnmount->setEnabled( true );
+
+    m_unmount_action->setEnabled( true );
   }
   else
   {
-    sapp->sharesUnmount->setEnabled( false );
-    sapp->sharesStartFilemanager->setEnabled( false );
-    sapp->sharesForceUnmount->setEnabled( false );
-    
-    sapp->core()->setShareForUsageInfo( NULL );
-    clearSelection();    
+    m_unmount_action->setEnabled( false );
+    m_filemanager_action->setEnabled( false );
+    m_force_action->setEnabled( false );
+
+    smb4k_core->setShareForUsageInfo( NULL );
+    clearSelection();
   }
-  
+
   if ( button == KIconView::RightButton )
   {
     KActionMenu *menu = new KActionMenu( this, "SharesViewPopupMenu" );
+
     menu->popupMenu()->insertTitle( SmallIcon( "hdd_mount" ), i18n( "Shares" ), 0, 0 );
-    menu->insert( sapp->actionCollection()->action( "shares_unmount_share" ) );
-    menu->insert( sapp->actionCollection()->action( "shares_force_unmount" ) );
-    menu->insert( sapp->actionCollection()->action( "shares_unmount_all" ) );
+    menu->insert( m_unmount_action );
+    menu->insert( m_force_action );
+    menu->insert( m_unmount_all_action );
     menu->popupMenu()->insertSeparator( -1 );
-    menu->insert( sapp->actionCollection()->action( "shares_manual_mount" ) );
+    menu->insert( m_manual_action );
     menu->popupMenu()->insertSeparator( -1 );
-    menu->insert( sapp->actionCollection()->action( "shares_start_filemanager" ) );
-    
+    menu->insert( m_filemanager_action );
+
     menu->popupMenu()->exec( pos, 0 );
   }
 }
@@ -206,21 +238,21 @@ void Smb4KShareWidget::slotSelectionChanged( QIconViewItem *item )
 
     if ( !i->isBroken() )
     {
-      sapp->sharesStartFilemanager->setEnabled( true );
-      sapp->core()->setShareForUsageInfo( i->shareObject() );
+      m_filemanager_action->setEnabled( true );
+      smb4k_core->setShareForUsageInfo( i->shareObject() );
     }
     else
     {
-      sapp->sharesStartFilemanager->setEnabled( false );
-      sapp->core()->setShareForUsageInfo( NULL );
+      m_filemanager_action->setEnabled( false );
+      smb4k_core->setShareForUsageInfo( NULL );
     }
-    
+
     if ( m_forcedUnmount )
     {
-      sapp->sharesForceUnmount->setEnabled( true );
+      m_force_action->setEnabled( true );
     }
-      
-    sapp->sharesUnmount->setEnabled( true );
+
+    m_unmount_action->setEnabled( true );
   }
 }
 
@@ -231,23 +263,22 @@ void Smb4KShareWidget::slotSelectionChanged( QIconViewItem *item )
 
 void Smb4KShareWidget::slotMountedShares()
 {
-  QValueList<Smb4KShare *> shares = sapp->core()->mounter()->getShares();
+  QValueList<Smb4KShare *> shares = smb4k_core->mounter()->getShares();
   Smb4KShareWidgetItem *current = (Smb4KShareWidgetItem *)currentItem();
-  
+
   if ( !shares.isEmpty() )
   {
     // First remove those, that are not mounted anymore:
     for ( Smb4KShareWidgetItem *item = (Smb4KShareWidgetItem *)this->firstItem(); item; item = (Smb4KShareWidgetItem *)item->nextItem() )
     {
-      if( !sapp->core()->mounter()->findShareByPath( item->mountpoint() )
-          || ( item->shareObject()->isForeign() && !m_showExternal ) )
+      if( !smb4k_core->mounter()->findShareByPath( item->mountpoint() ) ||
+          ( item->shareObject()->isForeign() && !m_showExternal ) )
       {
         if ( current == item )
         {
-          sapp->core()->setShareForUsageInfo( NULL );
+          smb4k_core->setShareForUsageInfo( NULL );
         }
-        
-        delete sapp->actionCollection()->action( ((Smb4KShareWidgetItem *)item)->name() );
+
         delete item;
         this->sort( this->sortDirection() );
       }
@@ -259,28 +290,21 @@ void Smb4KShareWidget::slotMountedShares()
       // Check, whether the share is already in the list. Look for the
       // mount point.
       bool alreadyInView = false;
-      
+
       for ( Smb4KShareWidgetItem *item = (Smb4KShareWidgetItem *)this->firstItem(); item; item = (Smb4KShareWidgetItem *)item->nextItem() )
       {
-        if ( item->mountpoint() == (*it)->getPath() || item->mountpoint() == (*it)->getCanonicalPath() )
+        if ( QString::compare( item->mountpoint(), (*it)->getPath() ) == 0 ||
+             QString::compare( item->mountpoint(), (*it)->getCanonicalPath() ) == 0 )
         {
           if ( (*it)->isBroken() && !item->isBroken() )
           {
             item->setBroken( true );
-            
-            KAction *a = sapp->actionCollection()->action( (*it)->getName() );
-            a->setEnabled( false );
-            a->setIcon( "file_broken" );
           }
           else if ( !(*it)->isBroken() && item->isBroken() )
           {
             item->setBroken( false );
-            
-            KAction *a = sapp->actionCollection()->action( (*it)->getName() );
-            a->setEnabled( true );
-            a->setIcon( "hdd_mount" );
           }
-          
+
           alreadyInView = true;
           break;
         }
@@ -292,70 +316,53 @@ void Smb4KShareWidget::slotMountedShares()
 
       if ( !alreadyInView )
       {
-        if ( m_display == "icons" && !m_showExternal && (*it)->isForeign() )
+        if ( QString::compare( m_display, "icons" ) == 0 && !m_showExternal && (*it)->isForeign() )
         {
           continue;
         }
-        else if ( m_display == "icons" )
+        else if ( QString::compare( m_display, "icons" ) == 0 )
         {
           new Smb4KShareWidgetItem( *it, this, Smb4KShareWidgetItem::Icons, m_mountpoint );
-
-          KAction *a = new KAction( (*it)->getName(), 0, 0, 0, 0, sapp->actionCollection(), (*it)->getName() );
-          a->setGroup( "MountedShares" );
-          a->setIcon( (*it)->isBroken() ? "file_broken" : "hdd_mount" );
-          a->setEnabled( !(*it)->isBroken() );
         }
 
-        if ( m_display == "list" && !m_showExternal && (*it)->isForeign() )
+        if ( QString::compare( m_display, "list" ) == 0 && !m_showExternal && (*it)->isForeign() )
         {
           continue;
         }
-        else if ( m_display == "list" )
+        else if ( QString::compare( m_display, "list" ) == 0 )
         {
           new Smb4KShareWidgetItem( *it, this, Smb4KShareWidgetItem::List, m_mountpoint );
-            
-          KAction *a = new KAction( (*it)->getName(), 0, 0, 0, 0, sapp->actionCollection(), (*it)->getName() );
-          a->setGroup( "MountedShares" );
-          a->setIcon( (*it)->isBroken() ? "file_broken" : "hdd_mount" );
-          a->setEnabled( !(*it)->isBroken() );
         }
 
         // Do the sorting:
         this->sort( this->sortDirection() );
       }
     }
-    
+
     if ( current != (Smb4KShareWidgetItem *)currentItem() )
     {
-      sapp->sharesUnmount->setEnabled( false );
-      sapp->sharesForceUnmount->setEnabled( false );
-      sapp->sharesStartFilemanager->setEnabled( false );
-      
+      m_unmount_action->setEnabled( false );
+      m_force_action->setEnabled( false );
+      m_filemanager_action->setEnabled( false );
+
       clearSelection();
-      sapp->shareTab()->clear();
+      emit clearedSelection();
     }
-    
-    sapp->sharesUnmountAll->setEnabled( true );
+
+    m_unmount_all_action->setEnabled( true );
   }
   else
   {
-    sapp->core()->setShareForUsageInfo( NULL );
+    smb4k_core->setShareForUsageInfo( NULL );
     delete current;
     clear();
-    
-    KActionPtrList list = sapp->actionCollection()->actions( "MountedShares" );
-    
-    for ( KActionPtrList::Iterator it = list.begin(); it != list.end(); ++it )
-    {
-      delete *it;
-    }
-    
-    sapp->sharesUnmount->setEnabled( false );
-    sapp->sharesForceUnmount->setEnabled( false );
-    sapp->sharesUnmountAll->setEnabled( false );
-    sapp->sharesStartFilemanager->setEnabled( false );    
-    
-    sapp->shareTab()->clear();
+
+    m_unmount_action->setEnabled( false );
+    m_force_action->setEnabled( false );
+    m_unmount_all_action->setEnabled( false );
+    m_filemanager_action->setEnabled( false );
+
+    emit cleared();
   }
 }
 
@@ -369,7 +376,7 @@ void Smb4KShareWidget::slotOpenFilemanager()
 {
   if ( currentItem() && !((Smb4KShareWidgetItem *)currentItem())->isBroken() )
   {
-    sapp->core()->open( ((Smb4KShareWidgetItem *)currentItem())->shareObject() );
+    smb4k_core->open( ((Smb4KShareWidgetItem *)currentItem())->shareObject() );
   }
 }
 
@@ -379,14 +386,14 @@ void Smb4KShareWidget::slotUnmountShare()
   if ( currentItem() )
   {
     Smb4KShareWidgetItem *i = (Smb4KShareWidgetItem *)currentItem();
-    sapp->core()->mounter()->unmountShare( i->mountpoint(), QString( "%1" ).arg( i->uid() ), QString( "%1" ).arg( i->gid() ) );
+    smb4k_core->mounter()->unmountShare( i->mountpoint(), QString( "%1" ).arg( i->uid() ), QString( "%1" ).arg( i->gid() ) );
   }
 }
 
 
 void Smb4KShareWidget::slotUnmountAllShares()
 {
-  sapp->core()->mounter()->unmountAllShares();
+  smb4k_core->mounter()->unmountAllShares();
 }
 
 
@@ -395,7 +402,7 @@ void Smb4KShareWidget::slotForceUnmountShare()
   if ( currentItem() )
   {
     Smb4KShareWidgetItem *i = (Smb4KShareWidgetItem *)currentItem();
-    sapp->core()->mounter()->forceUnmountShare( i->mountpoint(), QString( "%1" ).arg( i->uid() ), QString( "%1" ).arg( i->gid() ) );
+    smb4k_core->mounter()->forceUnmountShare( i->mountpoint(), QString( "%1" ).arg( i->uid() ), QString( "%1" ).arg( i->gid() ) );
   }
 }
 
@@ -414,11 +421,11 @@ void Smb4KShareWidget::slotManualMount()
  ***************************************************************************/
 
 
-Smb4KShareWidgetItem::Smb4KShareWidgetItem( Smb4KShare *share, Smb4KShareWidget *parent, int alignment, bool mp ) 
+Smb4KShareWidgetItem::Smb4KShareWidgetItem( Smb4KShare *share, Smb4KShareWidget *parent, int alignment, bool mp )
 : KIconViewItem( parent, QString::null ), m_share( *share ), m_alignment( alignment )
 {
   setBroken( m_share.isBroken() );
-     
+
   if ( mp )
   {
     setText( m_share.getPath() );
@@ -455,9 +462,9 @@ void Smb4KShareWidgetItem::paintItem( QPainter *p, const QColorGroup &cg )
 void Smb4KShareWidgetItem::setBroken( bool broken )
 {
   m_share.setBroken( broken );
-  
+
   if ( broken )
-  {  
+  {
     if ( !m_share.isForeign() && m_alignment == Icons )
     {
       setPixmap( DesktopIcon( "file_broken" ) );
