@@ -31,12 +31,13 @@
 #include <kiconview.h>
 #include <kconfig.h>
 #include <kprocess.h>
-#include <kiconloader.h>
+#include <kactioncollection.h>
+#include <kaction.h>
 
 // Application includes
 #include "../core/smb4kshare.h"
 
-/** 
+/**
  * This class provides the ability display the mounted shares
  * and manipulate them.
  */
@@ -47,45 +48,66 @@ class Smb4KShareWidget : public KIconView
 
   friend class Smb4KApp;
   friend class Smb4KShareWidgetItem;
-  
+
   public:
-    /** 
-     * The constructor. 
+    /**
+     * The constructor.
      */
     Smb4KShareWidget( QWidget *parent = 0, const char *name = 0 );
-    /** 
-     * The destructor. 
+    /**
+     * The destructor.
      */
     ~Smb4KShareWidget();
-    /** 
-     * Reads the options. 
+    /**
+     * Reads the options.
      */
     void readOptions();
+    /**
+     * This function returns a pointer to the action collection of this class.
+     * You should use it to include the action into the action collection of the
+     * main action collection (e.g. KMainWindow::actionCollection()).
+     *
+     * The entries in this action collection are members of the group "ShareWidget".
+     *
+     * @returns       a pointer to the action collection of this class
+     */
+    KActionCollection *action_collection() { return m_collection; }
+
+  signals:
+    /**
+     * This signal is emitted when the widget has been cleared, i. e. when alls
+     * shares have been unmounted.
+     */
+    void cleared();
+    /**
+     * This signal is emitted when the selection has been cleared.
+     */
+    void clearedSelection();
 
   protected slots:
-    /** 
-     * Is called by the menu. Does the unmounting. 
+    /**
+     * Is called by the menu. Does the unmounting.
      */
     void slotUnmountShare();
-    /** 
-     * Is called by the menu. Unmounts all shares at once. 
+    /**
+     * Is called by the menu. Unmounts all shares at once.
      */
     void slotUnmountAllShares();
-    /** 
-     * Is called by the menu. Forces the unmount of a share. 
+    /**
+     * Is called by the menu. Forces the unmount of a share.
      */
     void slotForceUnmountShare();
-    /** 
-     * Is called to import mounted shares into the share view. 
+    /**
+     * Is called to import mounted shares into the share view.
      */
     void slotMountedShares();
-    /** 
+    /**
      * Is called, when a share is to be opened with the filemanager.
      * This slot behaves exactly the same as slotItemExecuted(), except
-     * this is an external one. 
+     * this is an external one.
      */
     void slotOpenFilemanager();
-    /** 
+    /**
      * Is called when any mouse button was pressed.
      */
     void slotButtonPressed( int button, QIconViewItem *item, const QPoint &pos );
@@ -97,28 +119,57 @@ class Smb4KShareWidget : public KIconView
      * Is called when the user want to mount a share manually.
      */
     void slotManualMount();
-    
+
   private:
-    /** The KConfig variable. */
-    KConfig *m_config;
-    /** 
-     * Holds the display style. 
+    /**
+     * Holds the display style.
      */
     QString m_display;
-    /** Holds whether the mount point should be shown as description. */
+    /**
+     * Holds whether the mount point should be shown as description.
+     */
     bool m_mountpoint;
-    /** Determines whether all shares that were mounted should
-        be shown. */
+    /**
+     * Determines whether all shares that were mounted should be shown.
+     */
     bool m_showExternal;
     /**
      * Determines whether the user wants to force the unmounting of
      * dead shares or not.
      */
     bool m_forcedUnmount;
+    /**
+     * This is the action collection of this class.
+     */
+    KActionCollection *m_collection;
+    /**
+     * This function initializes the actions that are provided by this class.
+     */
+    void initActions();
+    /**
+     * The unmount action.
+     */
+    KAction *m_unmount_action;
+    /**
+     * Action to force the unmount.
+     */
+    KAction *m_force_action;
+    /**
+     * The unmount all action
+     */
+    KAction *m_unmount_all_action;
+    /**
+     * The manual mount action
+     */
+    KAction *m_manual_action;
+    /**
+     * The filemanager action
+     */
+    KAction *m_filemanager_action;
 };
 
 
-/** 
+/**
  * This class handles the icon view items that are to be displayed.
  */
 class Smb4KShareWidget;
@@ -179,7 +230,7 @@ class Smb4KShareWidgetItem : public KIconViewItem
      * Reimplemented from QIconViewItem.
      */
     void paintItem( QPainter *p, const QColorGroup &cg );
-  
+
   private:
     /**
      * The Smb4KShare object.
